@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 ###############################################################################
-# $Id$
+# $Id: install_perl_libs.pl 1798632 2017-06-13 19:39:45Z arkurth $
 ###############################################################################
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
@@ -63,20 +63,13 @@ my @LINUX_PACKAGES = (
 	'perl-DBD-MySQL',
 	'perl-DBI',
 	'perl-Digest-SHA1',
-	'perl-Expect',
-	'perl-Frontier-RPC',
-	'perl-Frontier-RPC-Client',
 	'perl-IO-String',
 	'perl-JSON',
-	'perl-LWP-Protocol-https',
 	'perl-MailTools',
-	'perl-Mo',
 	'perl-Net-Jabber',
 	'perl-Net-Netmask',
 	'perl-Net-SSH-Expect',
-	'perl-Object-InsideOut',
 	'perl-RPC-XML',
-	'perl-Scalar-List-Utils',
 	'perl-Text-CSV_XS',
 	'perl-Time-HiRes',
 	'perl-XML-Simple',
@@ -86,17 +79,20 @@ my @LINUX_PACKAGES = (
 
 my @PERL_MODULES = (
 	'CPAN',
-	'Crypt::CBC',
+	'DBI',
 	'Digest::SHA1',
 	'Frontier::Client',
-	'IO::String',
 	'LWP::Protocol::https',
+	'Mail::Mailer',
 	'Mo::builder',
-	'Net::Ping::External',
 	'Net::SSH::Expect',
 	'Object::InsideOut',
+	'RPC::XML',
 	'Scalar::Util',
-	'Text::CSV_XS',
+	'Term::ANSIColor',
+	'Time::HiRes',
+	'URI',
+	'YAML',
 );
 	
 # Store the command line options in hash
