@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 ###############################################################################
-# $Id$
+# $Id: ManagementNode.pm 1801511 2017-07-10 18:43:12Z arkurth $
 ###############################################################################
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
@@ -44,7 +44,7 @@ use lib "$FindBin::Bin/../../../..";
 use base qw(VCL::Module::OS::Linux);
 
 # Specify the version of this module
-our $VERSION = '2.5.2';
+our $VERSION = '2.5';
 
 # Specify the version of Perl to use
 use 5.008000;
@@ -509,13 +509,6 @@ sub run_stage_scripts_on_management_node {
 			next;
 		}
 		
-		# Ignore the .gitignore files
-		if ($script_file_path =~ /\.gitignore/i) {
-			my $matching_section = $1;
-			notify($ERRORS{'DEBUG'}, 0, "ignoring gitignore file on management node from script directory '$matching_section': $script_file_path");
-			next;
-		}
-		
 		my $command = "chmod +x $script_file_path && $script_file_path $mn_json_file_path";
 		my ($exit_status, $output) = $self->execute($command);
 		if (!defined($output)) {
