@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 ###############################################################################
-# $Id$
+# $Id: 8.pm 1803661 2017-08-01 15:43:55Z arkurth $
 ###############################################################################
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
@@ -39,7 +39,7 @@ use lib "$FindBin::Bin/../../../../..";
 use base qw(VCL::Module::OS::Windows::Version_6);
 
 # Specify the version of this module
-our $VERSION = '2.5.2';
+our $VERSION = '2.5';
 
 # Specify the version of Perl to use
 use 5.008000;
@@ -134,7 +134,7 @@ sub pre_capture {
 	}
 	
 	# Set the sshd service startup mode to disabled so that it does not start up until properly configured
-	if (!$self->set_service_startup_mode('sshd', 'disabled') && !$self->set_service_startup_mode('cygsshd', 'disabled')) {
+	if (!$self->set_service_startup_mode('sshd', 'disabled')) {
 		notify($ERRORS{'WARNING'}, 0, "sshd service could not be disabled before shutting down computer");
 		return;
 	}
