@@ -32,12 +32,13 @@ function help() {
 	echo "$name [-h|--help] [-d|--database] [-w|--web] [-m|--managementnode]"
 	echo -e "\t\t[--dbhost <hostname> --dbpass <password>] "
 	echo -e "\t\t[--mnhost <hostname>] [--webhost <hostname>]"
+	echo -e "\t\t[-t|--timezone <timezone>]"
 	echo ""
 	echo -e "\t-d|--database - install database server components"
 	echo -e "\t\t--dbpass, --mnhost, --mnip, --webhost, and --adminpass must also be specified"
 	echo ""
 	echo -e "\t-w|--web - install web server components"
-	echo -e "\t\t--dbhost and --dbpass must also be specified"
+	echo -e "\t\t--dbhost, --dbpass, and -t|--timezone must also be specified"
 	echo ""
 	echo -e "\t-m|--managementnode - install management node (vcld) components"
 	echo -e "\t\t--dbhost, --dbpass, and --adminpass must also be specified"
@@ -53,20 +54,22 @@ function help() {
 	echo ""
 	echo -e "\t--adminpass <password> - password for VCL admin user"
 	echo ""
-	echo "If no arguments supplied, all components will be install and you"
+	echo -e "\t-t|--timezone - timezone for web components"
+	echo ""
+	echo "If no arguments supplied, all components will be installed and you"
 	echo "will be prompted for any required additional information."
 	echo ""
 	exit 2
 }
 
-args=$(getopt -q -o dwmh -l database,web,managementnode,help,dbhost:,dbpass:,mnhost:,mnip:,webhost:,adminpass:,rc: -n $0 -- "$@")
+args=$(getopt -q -o dwmht: -l database,web,managementnode,help,dbhost:,dbpass:,mnhost:,mnip:,webhost:,adminpass:,timezone:,rc: -n $0 -- "$@")
 
 if [ $? -ne 0 ]; then help; fi
 
 eval set -- "$args"
 
 # ------------------------- variables -------------------------------
-VCL_VERSION=2.4.2
+VCL_VERSION=2.5
 DB_USERNAME=vcluser
 ADMIN_PASSWORD=
 
@@ -77,8 +80,9 @@ WEB_HOST=localhost
 CRYPTKEY=`random_string 20`
 PEMKEY=`random_string 20`
 ARCHIVE=apache-VCL-$VCL_VERSION.tar.bz2
-ARCHIVEURLPATH="http://vcl.apache.org/downloads/download.cgi?action=download&filename=%2Fvcl%2F"
-SIGPATH="http://www.apache.org/dist/vcl/"
+ARCHIVEURLPATH="http://vcl.apache.org/downloads/download.cgi?action=download&filename=%2Fvcl%2F$VCL_VERSION%2F"
+SIGPATH="https://www.apache.org/dist/vcl/$VCL_VERSION/"
+TZDEFAULT="America/New_York"
 
 DODB=0
 DOWEB=0
@@ -92,6 +96,7 @@ adminpassdefault=1
 webhostdefault=1
 DODHCP=no
 dorc=0
+TIMEZONE=''
 
 while true; do
 	case "$1" in
@@ -140,6 +145,10 @@ while true; do
 			adminpassdefault=0
 			shift 2
 			;;
+		-t|--timezone)
+			TIMEZONE=$2
+			shift 2
+			;;
 		--rc)
 			RC=$2
 		   dorc=1
@@ -193,11 +202,11 @@ if [[ $DODB -eq 1 && ($DOWEB -eq 0 || $DOMN -eq 0) && ($dbpassdefault -eq 1 || $
 	exit 1
 fi
 
-if [[ $DOWEB -eq 1 && ($DODB -eq 0 || $DOMN -eq 0) && ($dbhostdefault -eq 1 || $dbpassdefault -eq 1) ]]; then
+if [[ $DOWEB -eq 1 && ($DODB -eq 0 || $DOMN -eq 0) && ($dbhostdefault -eq 1 || $dbpassdefault -eq 1 || $TIMEZONE = '') ]]; then
 	echo ""
 	echo "Error missing arguments:"
 	echo ""
-	echo -e "\t-w or --web was specified but one of --dbhost or --dbpass was missing"
+	echo -e "\t-w or --web was specified but one of --dbhost, --dbpass, or -t|--timezone was missing"
 	echo ""
 	exit 1
 fi
@@ -220,6 +229,14 @@ if [[ $adminpassdefault -eq 0 && ($ADMIN_PASSWORD = ^[[:space:]]+$ || $ADMIN_PAS
 	exit 1
 fi
 
+if [[ ! $TIMEZONE = '' && ! $TIMEZONE =~ ^[-A-Za-z0-9/\+_]+$ ]]; then
+	echo ""
+	echo "Invalid value for timezone. Timezone can only contain these"
+	echo "characters: A-Z a-z 0-9 / - _ +"
+	echo ""
+	exit 1
+fi
+
 # ------------------------- check for being root -----------------------------
 who=$(whoami)
 if [[ $who != "root" ]]; then
@@ -283,6 +300,26 @@ if [[ $DOALL -eq 1 ]]; then
 	done
 fi
 
+if [[ $DOALL -eq 1 && $TIMEZONE = '' ]]; then
+	print_break
+	echo ""
+	echo "Enter the timezone to be used by the web components. A list of timezones supported by"
+	echo "php can be found here: http://php.net/manual/en/timezones.php"
+	echo "(If that URL is no longer valid, do a web search for \"php timezones\")"
+	echo -n "Timezone for web components [$TZDEFAULT]: "
+	IFS= read TIMEZONE
+
+	if [[ $TIMEZONE = ^[[:space:]]+$ || $TIMEZONE = "" ]]; then
+		TIMEZONE=$TZDEFAULT
+	fi
+
+	while [[ ! $TIMEZONE =~ ^[-A-Za-z0-9/\+_]+$ ]]; do
+		echo "Timezone can only contain the following characters: A-Z a-z 0-9 / - _ +"
+		echo -n "Timezone: "
+		IFS= read TIMEZONE
+	done
+fi
+
 # --------------------- public/private address selection ---------------------
 if [[ $DOMN -eq 1 ]]; then
 	print_break;
@@ -549,7 +586,7 @@ fi
 if [[ $DOWEB -eq 1 ]]; then
 	print_break
 	echo "Installing httpd and php components..."
-	yum -q -y install httpd php mod_ssl php php-gd php-mysql php-xml php-xmlrpc php-ldap sendmail php-mbstring
+	yum -q -y install httpd php mod_ssl php php-gettext php-mysql php-xml php-xmlrpc php-ldap sendmail php-mbstring
 	if [ $? -ne 0 ]; then generic_error "Failed to install httpd"; exit 1; fi;
 	echo "setting httpd to start on boot"
 	/sbin/chkconfig httpd on
@@ -676,6 +713,11 @@ if [[ $DOWEB -eq 1 ]]; then
 	ln -s /var/www/html/vcl-$VCL_VERSION /var/www/html/vcl
 	if [ $? -ne 0 ]; then generic_error "Failed to install VCL web code"; exit 1; fi;
 	chown apache /var/www/html/vcl/.ht-inc/maintenance
+	chown apache /var/www/html/vcl/.ht-inc/cryptkey
+	if [[ -x /usr/sbin/getenforce ]] && /usr/sbin/getenforce | grep -q -i enforcing; then
+		chcon -t httpd_sys_rw_content_t /var/www/html/vcl/.ht-inc/maintenance
+		chcon -t httpd_sys_rw_content_t /var/www/html/vcl/.ht-inc/cryptkey
+	fi
 fi
 
 # ---------------------------- configure web code --------------------------
@@ -697,6 +739,8 @@ if [[ $DOWEB -eq 1 ]]; then
 	echo "Configureing conf.php..."
 	/bin/cp -f /var/www/html/vcl/.ht-inc/conf-default.php /var/www/html/vcl/.ht-inc/conf.php
 	if [ $? -ne 0 ]; then echo "Error: Failed to configure conf.php"; exit 1; fi;
+	sed -i -r -e "s~date_default_timezone_set\('America/New_York'\);~date_default_timezone_set('$TIMEZONE');~" /var/www/html/vcl/.ht-inc/conf.php
+	if [ $? -ne 0 ]; then echo "Error: Failed to configure conf.php"; exit 1; fi;
 
 	echo "Generating keys..."
 	cd /var/www/html/vcl/.ht-inc
