@@ -134,7 +134,7 @@ function selectAuth() {
 		$authtype = $_COOKIE['VCLAUTHSEL'];
 	if(array_key_exists('clearselection', $_GET) && $_GET['clearselection'] == 1) {
 		setcookie("VCLAUTHSEL", '', time() - 10, "/", COOKIEDOMAIN);
-		unset($authtype);
+		$authtype = '';
 	}
 	if(array_key_exists($authtype, $authMechs)) {
 		if(array_key_exists('remsel', $_POST) && $_POST['remsel'] == 1)
@@ -154,13 +154,13 @@ function selectAuth() {
 	$HTMLheader = getHeader(0);
 	print $HTMLheader;
 	$printedHTMLheader = 1;
-	print "<H2>" . _("Welcome to the Virtual Computing Lab") . "</H2>\n";
-	print "<TABLE>\n";
-	print "<TR>\n";
-	print "<TD nowrap class=rightborder>\n";
-	print _("Please select an authentication method to use:") . "<br><br>\n";
+	print "<H2>" . i("Welcome to the Virtual Computing Lab") . "</H2>\n";
+	print "<div id=\"loginlayout\">\n";
+	print "<div id=\"loginform\">\n";
+	print i("Please select an authentication method to use:") . "<br><br>\n";
 	if(strlen($authtype))
-		print "<font color=red>" . _("Selected method failed, please try again") . "</font><br>\n";
+		print "<font color=red>" . i("Selected method failed, please try again") . "</font><br>\n";
+	$methods = array();
 	foreach(array_keys($authMechs) as $mech)
 		$methods["$mech"] = $mech;
 	print "<FORM action=\"" . BASEURL . SCRIPT . "\" method=post name=loginform>\n";
@@ -172,19 +172,18 @@ function selectAuth() {
 		printSelectInput("authtype", $methods, -1, 0, 0, '', 'tabindex=1');
 	print "<br><INPUT type=hidden name=mode value=selectauth>\n";
 	print "<input type=checkbox id=remsel name=remsel value=1 tabindex=2>\n";
-	print "<label for=remsel>" . _("Remember my selection") . "</label><br>\n";
-	print "<INPUT type=submit value=\"" . _("Proceed to Login") . "\" tabindex=3 name=userid>\n";
+	print "<label for=remsel>" . i("Remember my selection") . "</label><br>\n";
+	print "<INPUT type=submit value=\"" . i("Proceed to Login") . "\" tabindex=3 name=userid>\n";
 	print "</FORM>\n";
-	print "</TD>\n";
-	print "<TD>\n";
-	print "<h3>" . _("Explanation of authentication methods:") . "</h3>\n";
+	print "</div>\n"; # loginform
+	print "<div id=\"loginhelp\">\n";
+	print "<h3>" . i("Explanation of authentication methods:") . "</h3>\n";
 	print "<UL id=expauthul>\n";
 	foreach($authMechs as $mech)
 		print "<LI>{$mech['help']}</LI>\n";
 	print "</UL>\n";
-	print "</TD>\n";
-	print "</TR>\n";
-	print "</TABLE>\n";
+	print "</div>\n"; # loginhelp
+	print "</div>\n"; # loginlayout
 	print getFooter();
 }
 
@@ -229,10 +228,10 @@ function printLoginPage($servertimeout=0) {
 	if(isset($_GET['userid']))
 		unset($_GET['userid']);
 	$userid = processInputVar('userid', ARG_STRING, '');
-	if($userid == _('Proceed to Login'))
+	if($userid == i('Proceed to Login'))
 		$userid = '';
 	if(! array_key_exists($authtype, $authMechs)) {
-		// FIXME - hackish
+		header("Location: " . BASEURL . SCRIPT);
 		dbDisconnect();
 		exit;
 	}
@@ -241,7 +240,7 @@ function printLoginPage($servertimeout=0) {
 	$userid = htmlspecialchars($userid);
 	$extrafailedmsg = '';
 	if($servertimeout)
-		$extrafailedmsg = " " . _("(unable to connect to authentication server)");
+		$extrafailedmsg = " " . i("(unable to connect to authentication server)");
 	/*if($skin == 'example1') {
 		$useridLabel = 'Pirateid';
 		$passLabel = 'Passphrase';
@@ -279,16 +278,17 @@ function printLoginPage($servertimeout=0) {
 		return;
 	}
 	else {*/
-		$useridLabel = _('Userid');
-		$passLabel = _('Password');
-		$text1 = _("Login with") . " $authtype";
+		$useridLabel = i('Userid');
+		$passLabel = i('Password');
+		$text1 = i("Login with") . " $authtype";
 		$text2 = "";
 	#}
+	print "<div id=\"loginbox\">\n";
 	print "<H2 style=\"display: block\">$text1</H2>\n";
 	print "<FORM action=\"" . BASEURL . SCRIPT . "\" method=post name=loginform>\n";
 	if(strlen($userid))
-		print "<font color=red>" . _("Login failed") . " $extrafailedmsg</font>\n";
-	print "<TABLE>\n";
+		print "<font color=red>" . i("Login failed") . " $extrafailedmsg</font>\n";
+	print "<TABLE id=\"loginlayout\">\n";
 	print "  <TR>\n";
 	print "    <TH align=right>$useridLabel:</TH>\n";
 	print "    <TD><INPUT type=text name=userid value=\"$userid\"></TD>\n";
@@ -298,14 +298,19 @@ function printLoginPage($servertimeout=0) {
 	print "    <TD><INPUT type=password name=password></TD>\n";
 	print "  </TR>\n";
 	print "  <TR>\n";
-	print "    <TD colspan=2 align=right><INPUT type=submit value=\"" . _("Login") . "\"></TD>\n";
+	print "    <TD colspan=2 align=right><INPUT type=submit value=\"" . i("Login") . "\"></TD>\n";
+	print "  </TR>\n";
+	print "  <TR>\n";
+	print "    <TD colspan=2 align=center><br><br><small>";
+	print "<a href=\"" . BASEURL . SCRIPT . "?mode=selectauth&clearselection=1\">";
+	print i("Select a different authentication method") . "</a></small></TD>\n";
 	print "  </TR>\n";
 	print "</TABLE>\n";
-	$cdata = array('authtype' => $authtype);
-	$cont = addContinuationsEntry('submitLogin', $cdata);
-	print "<INPUT type=hidden name=continuation value=\"$cont\">\n";
+	print "<input type=\"hidden\" name=\"mode\" value=\"submitLogin\">\n";
+	print "<input type=\"hidden\" name=\"authtype\" value=\"$authtype\">\n";
 	print "</FORM>\n";
 	print "$text2<br>\n";
+	print "</div>\n";
 	print getFooter();
 }
 
@@ -481,7 +486,8 @@ function localLogin($userid, $passwd, $authtype) {
 		else
 			setcookie("VCLAUTH", "{$cookie['data']}", 0, "/", COOKIEDOMAIN);
 		//load main page
-		setcookie("VCLSKIN", "default", (time() + (SECINDAY * 31)), "/", COOKIEDOMAIN);
+		$theme = getAffiliationTheme($authMechs[$authtype]['affiliationid']);
+		setcookie("VCLSKIN", $theme, (time() + (SECINDAY * 31)), "/", COOKIEDOMAIN);
 		header("Location: " . BASEURL . SCRIPT);
 		dbDisconnect();
 		exit;
@@ -570,6 +576,8 @@ function addLoginLog($login, $mech, $affiliationid, $passfail, $code='none') {
 	       .        "'{$_SERVER['REMOTE_ADDR']}', "
 	       .        "'$code')";
 	doQuery($query, 101);
+	if($passfail == 1)
+		checkMissingWebSecretKeys();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -622,7 +630,7 @@ function checkExpiredDemoUser($userid, $groups=0) {
 				updateGroups(array($nodemoid), $userid);
 				checkUpdateServerRequestGroups($groupid);
 				if(empty($skin)) {
-					$skin = 'default';
+					$skin = getAffiliationTheme(0);
 					require_once("themes/$skin/page.php");
 				}
 				$mode = 'expiredemouser';
