@@ -29,6 +29,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 function dashboard() {
 	print "<h2>VCL Dashboard</h2>\n";
+	print "(Times and dates on this page are in " . date('T') . ")<br><br>\n";
 	if(checkUserHasPerm('View Dashboard (global)')) {
 		print "View data for:";
 		$affils = getAffiliations();
@@ -37,30 +38,28 @@ function dashboard() {
 		$affils = array_reverse($affils, TRUE);
 		printSelectInput('affilid', $affils, -1, 0, 0, 'affilid', 'onChange="updateDashboard();"');
 	}
-	print "<table summary=\"\" id=dashboard>\n";
-	print "<tr>\n";
+	print "<div id=\"dashlayout\">\n";
 
 	# -------- left column ---------
-	print "<td valign=\"top\">\n";
+	print "<div id=\"dashleft\">\n";
 	print addWidget('status', 'Current Status');
 	print addWidget('topimages', 'Top 5 Images in Use', '(Reservations &lt; 24 hours long)');
 	print addWidget('toplongimages', 'Top 5 Long Term Images in Use', '(Reservations &gt; 24 hours long)');
 	print addWidget('toppastimages', 'Top 5 Images From Past Day', '(Reservations with a start<br>time within past 24 hours)');
 	print addWidget('topfailedcomputers', 'Top Recent Computer Failures', '(Failed in the last 5 days)');
 	print addWidget('blockallocation', 'Block Allocation Status');
-	print "</td>\n";
+	print "</div>\n"; # dashleft
 	# -------- end left column ---------
 
 	# ---------- right column ---------
-	print "<td valign=\"top\">\n";
+	print "<div id=\"dashright\">\n";
 	print addWidget('managementnodes', 'Management Nodes', '[ ] denotes node in maintenance state');
 	print addWidget('topfailed', 'Top Recent Image Failures', '(Failed in the last 5 days)');
 	print addLineChart('reschart', 'Past 12 Hours of Active Reservations');
-	print "</td>\n";
+	print "</div>\n"; # dashright
 	# -------- end right column --------
 
-	print "</tr>\n";
-	print "</table>\n";
+	print "</div>\n"; # dashlayout
 	print addWidget('newreservations', 'Notable Reservations', '');
 	if(checkUserHasPerm('View Dashboard (global)'))
 		print addWidget('failedimaging', 'Failed Imaging Reservations', '(Imaging Reservations in the maintenance state)');
@@ -693,8 +692,8 @@ function getNewReservationData() {
 	       . "LEFT JOIN user u ON (u.id = rq.userid) "
 	       . "LEFT JOIN user u2 ON (u2.id = c.ownerid) "
 	       . "LEFT JOIN affiliation af ON (af.id = u.affiliationid) "
-	       . "WHERE ((rq.stateid IN (6, 13, 19) AND rq.start < NOW()) OR "
-	       .       "(rq.stateid = 14 AND rq.laststateid IN (6, 13, 16, 19) AND "
+	       . "WHERE ((rq.stateid IN (6, 13, 16, 19, 24) AND rq.start < NOW()) OR "
+	       .       "(rq.stateid = 14 AND rq.laststateid IN (6, 13, 16, 19, 24) AND "
 			 .       "rq.start < DATE_ADD(NOW(), INTERVAL 1 HOUR))) ";
 	if($affilid)
 		$query .= "AND (u.affiliationid = $affilid OR u2.affiliationid = $affilid) ";
@@ -732,6 +731,7 @@ function getFailedImagingData() {
 	$affilid = getDashboardAffilID();
 	$query = "SELECT c.hostname AS computer, "
 	       .        "i.prettyname AS image, "
+	       .        "ir.comments AS revisioncomments, "
 	       .        "rq.id, "
 	       .        "rq.start, "
 	       .        "o.installtype, "
@@ -742,20 +742,25 @@ function getFailedImagingData() {
 	       . "LEFT JOIN reservation rs ON (rs.requestid = rq.id) "
 	       . "LEFT JOIN computer c ON (c.id = rs.computerid) "
 	       . "LEFT JOIN image i ON (i.id = rs.imageid) "
+	       . "LEFT JOIN imagerevision ir ON (ir.id = rs.imagerevisionid) "
 	       . "LEFT JOIN OS o ON (o.id = i.OSid) "
 	       . "LEFT JOIN managementnode m ON (m.id = rs.managementnodeid) "
 	       . "LEFT JOIN vmhost vh ON (c.vmhostid = vh.id) "
 	       . "LEFT JOIN computer ch ON (vh.computerid = ch.id) "
 	       . "LEFT JOIN user u ON (rq.userid = u.id) "
 	       . "LEFT JOIN user u2 ON (u2.id = c.ownerid) "
-	       . "WHERE rq.stateid = 10 AND "
-	       .       "rq.laststateid = 16 ";
+	       . "LEFT JOIN state s1 ON (s1.id = rq.stateid) "
+	       . "LEFT JOIN state s2 ON (s2.id = rq.laststateid) "
+	       . "WHERE s1.name = 'maintenance' AND "
+	       .       "s2.name IN ('image','checkpoint')";
 	if($affilid)
 		$query .= "AND (u.affiliationid = $affilid OR u2.affiliationid = $affilid) ";
 	$query .= "ORDER BY rq.start";
 	$qh = doQuery($query, 101);
 	$data = array();
 	while($row = mysql_fetch_assoc($qh)) {
+		if(is_null($row['revisioncomments']))
+			$row['revisioncomments'] = '(none)';
 		$tmp = explode('.', $row['computer']);
 		$row['computer'] = $tmp[0];
 		$tmp = explode('.', $row['vmhost']);
@@ -850,7 +855,8 @@ function AJrestartImageCapture() {
 		return;
 	}
 	$request = getRequestInfo($requestid);
-	if($request['stateid'] != 10 || $request['laststateid'] != 16 ||
+	if($request['stateid'] != 10 ||
+	   ($request['laststateid'] != 16 && $request['laststateid'] != 24) ||
 	   count($request['reservations']) > 1) {
 		sendJSON(array('status' => 'wrongstate'));
 		return;
@@ -859,7 +865,7 @@ function AJrestartImageCapture() {
 	$query = "UPDATE computer c, "
 	       .        "request rq "
 	       . "SET c.stateid = 8, "
-	       .     "rq.stateid = 16, "
+	       .     "rq.stateid = {$request['laststateid']}, "
 	       .     "rq.laststateid = 10 "
 	       . "WHERE c.id = $compid AND "
 	       .       "rq.id = $requestid";
