@@ -48,16 +48,12 @@ function viewGroups() {
 	global $user, $mode;
 	$modetype = getContinuationVar("type");
 
-	print "<H2 id=\"startscroll\">User Groups</H2>\n";
+	print "<H2>User Groups</H2>\n";
 	if($modetype == "user") {
 		if($mode == "submitAddGroup") {
 			print "<font color=\"#008000\">User group successfully added";
 			print "</font><br><br>\n";
 		}
-		elseif($mode == "submitDeleteGroup") {
-			print "<font color=\"#008000\">User group successfully deleted";
-			print "</font><br><br>\n";
-		}
 		elseif($mode == "submitEditGroup") {
 			print "<font color=\"#008000\">User group successfully updated";
 			print "</font><br><br>\n";
@@ -81,11 +77,12 @@ function viewGroups() {
 	# hidden elements
 	$cont = addContinuationsEntry('editGroup', $cdata);
 	print "<input type=\"hidden\" id=\"editgroupcont\" value=\"$cont\">\n";
-	$cont = addContinuationsEntry('confirmDeleteGroup', $cdata);
+	$cont = addContinuationsEntry('AJconfirmDeleteGroup', $cdata);
 	print "<input type=\"hidden\" id=\"deletegroupcont\" value=\"$cont\">\n";
 	$cont = addContinuationsEntry('jsonUserGroupStore');
-	print "<div dojoType=\"dojo.data.ItemFileReadStore\" url=\"" . BASEURL;
-	print SCRIPT . "?continuation=$cont\" jsid=\"usergroupstore\"></div>\n";
+	print "<div dojoType=\"dojo.data.ItemFileWriteStore\" url=\"" . BASEURL;
+	print SCRIPT . "?continuation=$cont\" jsid=\"usergroupstore\" ";
+	print "comparatorMap=\"\{\}\"></div>\n";
 	print "<div dojoType=\"dojo.data.ItemFileWriteStore\"\n";
 	print "data=\"{'identifier':'id', 'label':'name', 'items':[]}\" \n";
 	print "jsid=\"affiliationstore\"></div>\n";
@@ -143,10 +140,11 @@ function viewGroups() {
 	print "<thead>\n";
 	print "<tr>\n";
 	if(preg_match('/MSIE/i', $_SERVER['HTTP_USER_AGENT']) ||
-	   preg_match('/Trident/i', $_SERVER['HTTP_USER_AGENT']))
-		$w = array('54px', '38px', '200px', '142px', '65px', '142px', '59px', '58px', '63px', '73px');
+	   preg_match('/Trident/i', $_SERVER['HTTP_USER_AGENT']) ||
+	   preg_match('/Edge/i', $_SERVER['HTTP_USER_AGENT']))
+		$w = array('54px', '43px', '200px', '142px', '65px', '142px', '59px', '58px', '63px', '73px');
 	else
-		$w = array('4.5em', '3em', '17em', '12em', '5em', '12em', '5em', '5em', '5.6em', '6.3em');
+		$w = array('4.8em', '3.5em', '17em', '12em', '5em', '12em', '5em', '5em', '5.6em', '6.3em');
 	print "<th field=\"id\" width=\"{$w[0]}\" formatter=\"fmtUserGroupDeleteBtn\">&nbsp;</th>\n";
 	print "<th field=\"id\" width=\"{$w[1]}\" formatter=\"fmtUserGroupEditBtn\">&nbsp;</th>\n";
 	print "<th field=\"name\" width=\"{$w[2]}\">Name</th>\n";
@@ -171,10 +169,6 @@ function viewGroups() {
 			print "<font color=\"#008000\">Resource group successfully added";
 			print "</font><br><br>\n";
 		}
-		elseif($mode == "submitDeleteGroup") {
-			print "<font color=\"#008000\">Resource group successfully deleted";
-			print "</font><br><br>\n";
-		}
 		elseif($mode == "submitEditGroup") {
 			print "<font color=\"#008000\">Resource group successfully updated";
 			print "</font><br><br>\n";
@@ -212,12 +206,12 @@ function viewGroups() {
 	# hidden elements
 	$cont = addContinuationsEntry('editGroup', $cdata);
 	print "<input type=\"hidden\" id=\"editresgroupcont\" value=\"$cont\">\n";
-	$cont = addContinuationsEntry('confirmDeleteGroup', $cdata);
+	$cont = addContinuationsEntry('AJconfirmDeleteGroup', $cdata);
 	print "<input type=\"hidden\" id=\"deleteresgroupcont\" value=\"$cont\">\n";
 	$jscont = addContinuationsEntry('jsonGetGroupInfo');
 	print "<input type=\"hidden\" id=\"jsongroupinfocont\" value=\"$jscont\">\n";
 	$cont = addContinuationsEntry('jsonResourceGroupStore');
-	print "<div dojoType=\"dojo.data.ItemFileReadStore\" url=\"" . BASEURL;
+	print "<div dojoType=\"dojo.data.ItemFileWriteStore\" url=\"" . BASEURL;
 	print SCRIPT . "?continuation=$cont\" jsid=\"resourcegroupstore\"></div>\n";
 	print "<div dojoType=\"dojo.data.ItemFileWriteStore\"\n";
 	print "data=\"{'identifier':'id', 'label':'name', 'items':[]}\" \n";
@@ -265,10 +259,11 @@ function viewGroups() {
 	print "<thead>\n";
 	print "<tr>\n";
 	if(preg_match('/MSIE/i', $_SERVER['HTTP_USER_AGENT']) ||
-	   preg_match('/Trident/i', $_SERVER['HTTP_USER_AGENT']))
-		$w = array('54px', '38px', '108px', '240px', '250px', '24px');
+	   preg_match('/Trident/i', $_SERVER['HTTP_USER_AGENT']) ||
+	   preg_match('/Edge/i', $_SERVER['HTTP_USER_AGENT']))
+		$w = array('54px', '43px', '108px', '240px', '250px', '24px');
 	else
-		$w = array('4.5em', '3em', '9em', '20em', '21em', '1.6em');
+		$w = array('4.5em', '3.5em', '9em', '20em', '21em', '1.6em');
 
 	print "<th field=\"id\" width=\"{$w[0]}\" formatter=\"fmtResourceGroupDeleteBtn\">&nbsp;</th>\n";
 	print "<th field=\"id\" width=\"{$w[1]}\" formatter=\"fmtResourceGroupEditBtn\">&nbsp;</th>\n";
@@ -283,6 +278,15 @@ function viewGroups() {
 	print "</thead>\n";
 	print "</table>\n";
 	print "</div>\n";
+
+	print "<div id=\"confirmDeleteDialog\" dojoType=\"dijit.Dialog\">\n";
+	print "<h2 id=\"confirmDeleteHeading\"></h2>\n";
+	print "<div id=\"confirmDeleteQuestion\"></div><br>\n";
+	print "<div id=\"confdelcontent\"></div><br>\n";
+	print dijitButton('deleteBtn', i("Delete Group"), "submitDeleteGroup();");
+	print dijitButton('', i("Cancel"), "clearHideConfirmDelete();");
+	print "<input type=hidden id=\"submitdeletecont\">\n";
+	print "</div>\n";
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -307,7 +311,7 @@ function jsonUserGroupStore() {
 	elseif(checkUserHasPerm('Manage Federated User Groups (affiliation only)'))
 		$showfederatedaffil = 1;
 	$items = array();
-	$lengths = getReservationLengths(65535);
+	$lengths = getReservationLengths(201600);
 	foreach($affilusergroups as $id => $group) {
 		if($group['name'] == 'None' || preg_match('/^\s*None/', $group['name']))
 			continue;
@@ -553,7 +557,7 @@ function editOrAddGroup($state) {
 			if($state) {
 				$data["name"] = '';
 				$data["affiliationid"] = $user['affiliationid'];
-				$data["owner"] = $user['unityid'];
+				$data["owner"] = "{$user['unityid']}@{$user['affiliation']}";
 				if(array_key_exists('VCLEDITGROUPID', $_COOKIE) &&
 				   (array_key_exists($_COOKIE['VCLEDITGROUPID'], $affilusergroups) ||
 				   $_COOKIE['VCLEDITGROUPID'] == $defaultusergroupid))
@@ -660,8 +664,11 @@ function editOrAddGroup($state) {
 				print "Type: Federated<br><br>\n";
 			$editusergroup = 1;
 		}
-		else
+		else {
 			print "<H2>Edit Resource Group</H2>\n";
+			list($junk, $name) = explode('/', $resourcegroups[$data['groupid']]["name"]);
+			print "$name<br><br>\n";
+		}
 	}
 	if(($state && $data["type"] == "user") || $data["isowner"] ||
 		$data["type"] == "resource") {
@@ -688,15 +695,24 @@ function editOrAddGroup($state) {
 			$tmp = explode('@', $usergroups[$groupid]['name']);
 			if($tmp[0] == 'Specify End Time' ||
 				$tmp[0] == 'Allow No User Check' ||
-				$tmp[0] == 'Default for Editable by')
+				$tmp[0] == 'Default for Editable by' ||
+				$tmp[0] == 'manageNewImages')
 				$editname = 0;
 		}
-		if($data['type'] == 'resource' ||
-		   ($editname && $data['courseroll'] == 0 && $data['custom'] == 1)) {
+		if($data['type'] == 'user' && $state == 0 &&
+		   ($data['courseroll'] == 1 || $data['custom'] == 0)) {
+			$editname = 0;
+		}
+		if($data['type'] == 'resource' && $state == 0 &&
+		   ($resourcegroups[$groupid]['name'] == 'computer/newimages' ||
+			$resourcegroups[$groupid]['name'] == 'computer/newvmimages')) {
+			$editname = 0;
+		}
+		if($editname) {
 			print "  <TR>\n";
 			print "    <TH align=right>Name:</TH>\n";
 			print "    <TD><INPUT type=text name=name value=\"{$data['name']}\" ";
-			print "maxlength=30>";
+			print "maxlength=60 size=60>";
 			if($data['type'] == 'user' && $selectAffil) {
 				print "@";
 				printSelectInput('affiliationid', $affils, $data['affiliationid']);
@@ -768,7 +784,7 @@ function editOrAddGroup($state) {
 			print "  <TR>\n";
 			print "    <TH align=right>Initial Max Time:</TH>\n";
 			print "    <TD>";
-			$lengths = getReservationLengths(65535);
+			$lengths = getReservationLengths(201600);
 			if(! array_key_exists($data['initialmax'], $lengths))
 				$data['initialmax'] = getReservationLengthCeiling($data['initialmax']);
 			printSelectInput("initialmax", $lengths, $data['initialmax']);
@@ -861,6 +877,8 @@ function editOrAddGroup($state) {
 			               'groupid' => $data['groupid'],
 			               'isowner' => $data['isowner'],
 			               'editname' => $editname);
+			if($editname == 0)
+				$cdata['name'] = $data['name'];
 			if($data['type'] == 'resource') {
 				$cdata['resourcetypeid'] = $resourcetypeid;
 				if(! empty($dispUserGrpIDs))
@@ -869,10 +887,8 @@ function editOrAddGroup($state) {
 					$cdata['ownergroupids'] = implode(',', array_keys($dispUserGrpIDsAllAffils));
 			}
 			else {
-				if($data['courseroll'] == 1 || $data['custom'] == 0 || $editname == 0) {
-					$cdata['name'] = $data['name'];
+				if($editname == 0)
 					$cdata['affiliationid'] = $data['affiliationid'];
-				}
 				$cdata['selectAffil'] = $selectAffil;
 				$cdata['groupwasnone'] = $groupwasnone;
 				$cdata['custom'] = $data['custom'];
@@ -916,7 +932,7 @@ function editOrAddGroup($state) {
 			$edit = 0;
 		if(empty($groupmembers) && ! $edit)
 			print "(empty group)<br>\n";
-		print "<TABLE border=1>\n";
+		print "<TABLE border=1 id=\"groupmembershiptbl\">\n";
 		if($edit) {
 			print "  <TR>\n";
 			print "  <FORM action=\"" . BASEURL . SCRIPT . "\" method=post>\n";
@@ -1005,16 +1021,16 @@ function processGroupInput($checks=1) {
 	
 	if($return['custom'] == 1 && $return['courseroll'] == 0 && $editname) {
 		if($return['type'] == 'user' &&
-		   ! preg_match('/^[-a-zA-Z0-9_\.: ]{3,30}$/', $return["name"])) {
+		   ! preg_match('/^[-a-zA-Z0-9_\.: ]{3,60}$/', $return["name"])) {
 			$submitErr |= GRPNAMEERR;
-			$submitErrMsg[GRPNAMEERR] = "Name must be between 3 and 30 characters "
+			$submitErrMsg[GRPNAMEERR] = "Name must be between 3 and 60 characters "
 			                          . "and can only contain letters, numbers, "
 			                          . "spaces, and these characters: - . _ :";
 		}
 		elseif($return['type'] == 'resource' &&
-		   ! preg_match('/^[-a-zA-Z0-9_\. ]{3,30}$/', $return["name"])) {
+		   ! preg_match('/^[-a-zA-Z0-9_\. ]{3,60}$/', $return["name"])) {
 			$submitErr |= GRPNAMEERR;
-			$submitErrMsg[GRPNAMEERR] = "Name must be between 3 and 30 characters "
+			$submitErrMsg[GRPNAMEERR] = "Name must be between 3 and 60 characters "
 			                          . "and can only contain letters, numbers, "
 			                          . "spaces, and these characters: - . _";
 		}
@@ -1336,6 +1352,7 @@ function checkForGroupUsage($groupid, $type, &$msg='') {
 			$msg = "$name is currently in use in the following ways. It "
 			     . "cannot be deleted until it is no longer in use.<br><br>\n"
 			     . implode("<br>\n", $msgs);
+			$msg = wordwrap($msg, 75, "<br>");
 			return 1;
 		}
 		return 0;
@@ -1369,6 +1386,7 @@ function checkForGroupUsage($groupid, $type, &$msg='') {
 		$msg = "$name is currently in use in the following ways. It "
 		     . "cannot be deleted until it is no longer in use.<br><br>\n"
 		     . implode("<br>\n", $msgs);
+		$msg = wordwrap($msg, 75, "<br>");
 		return 1;
 	}
 	return 0;
@@ -1428,8 +1446,8 @@ function confirmEditOrAddGroup($state) {
 	print "<DIV align=center>\n";
 	print "<H2>$title</H2>\n";
 	print "$question<br><br>\n";
-	if($data['courseroll'] == 1 || $data['custom'] == 0 || $editname == 0) {
-		if($user['showallgroups'])
+	if($editname == 0) {
+		if($data['type'] == 'user' && $user['showallgroups'])
 			print "{$data['name']}@{$affils[$data['affiliationid']]}<br><br>\n";
 		else
 			print "{$data['name']}<br><br>\n";
@@ -1470,7 +1488,7 @@ function confirmEditOrAddGroup($state) {
 			print "    <TD>" . $usergroups[$data["editgroupid"]]["name"] . "</TD>\n";
 			print "  </TR>\n";
 		}
-		$lengths = getReservationLengths(65535);
+		$lengths = getReservationLengths(201600);
 		print "  <TR>\n";
 		print "    <TH align=right>Initial Max Time:</TH>\n";
 		print "    <TD>{$lengths[$data["initialmax"]]}</TD>\n";
@@ -1561,14 +1579,14 @@ function submitAddGroup() {
 
 ////////////////////////////////////////////////////////////////////////////////
 ///
-/// \fn confirmDeleteGroup()
+/// \fn AJconfirmDeleteGroup()
 ///
-/// \brief prints a form to confirm the deletion of an group
+/// \brief generates and sends content prompting user to confirm deletion of
+/// group
 ///
 ////////////////////////////////////////////////////////////////////////////////
-function confirmDeleteGroup() {
+function AJconfirmDeleteGroup() {
 	global $user;
-	$groupid = getContinuationVar("groupid");
 	$type = getContinuationVar("type");
 
 	$usergroups = getUserGroups();
@@ -1576,8 +1594,10 @@ function confirmDeleteGroup() {
 	$groupid = processInputVar('groupid', ARG_NUMERIC);
 	if($type == 'user') {
 		if(! array_key_exists($groupid, $usergroups)) {
-			print "<h2>Delete User Group</h2>\n";
-			print "The selected user group does not exist.\n";
+			$rt = array('status' => 'nogroup',
+			            'title' => _('Delete User Group Error'),
+			            'msg' => _('The selected user group was not found.'));
+			sendJSON($rt);
 			return;
 		}
 		if($usergroups[$groupid]['ownerid'] != $user['id']) {
@@ -1586,14 +1606,18 @@ function confirmDeleteGroup() {
 				if(! checkUserHasPerm('Manage Federated User Groups (global)') &&
 				   (! checkUserHasPerm('Manage Federated User Groups (affiliation only)') ||
 				   $usergroups[$groupid]['groupaffiliationid'] != $user['affiliationid'])) {
-					print "<h2>Delete User Group</h2>\n";
-					print "You do not have access to delete the selected user group.\n";
+					$rt = array('status' => 'noaccess',
+					            'title' => _('Delete User Group Error'),
+					            'msg' => _('You do not have access to delete the selected user group.'));
+					sendJSON($rt);
 					return;
 				}
 			}
 			else {
-				print "<h2>Delete User Group</h2>\n";
-				print "You do not have access to delete the selected user group.\n";
+				$rt = array('status' => 'noaccess',
+				            'title' => _('Delete User Group Error'),
+				            'msg' => _('You do not have access to delete the selected user group.'));
+				sendJSON($rt);
 				return;
 			}
 		}
@@ -1602,9 +1626,12 @@ function confirmDeleteGroup() {
 		if($usergroups[$groupid]['groupaffiliationid'] == 1 &&
 		   ($checkname == 'Specify End Time' ||
 		   $checkname == 'Allow No User Check' ||
-		   $checkname == 'Default for Editable by')) {
-			print "<h2>Delete User Group</h2>\n";
-			print "{$usergroups[$groupid]['name']} is a system group that cannot be deleted";
+		   $checkname == 'Default for Editable by' ||
+		   $checkname == 'manageNewImages')) {
+			$rt = array('status' => 'noaccess',
+			            'title' => _('Delete User Group Error'),
+			            'msg' => sprintf(_('%s is a system group that cannot be deleted'), "<strong>{$usergroups[$groupid]['name']}</strong>"));
+			sendJSON($rt);
 			return;
 		}
 	}
@@ -1619,8 +1646,10 @@ function confirmDeleteGroup() {
 			}
 		}
 		if($noaccess) {
-			print "<h2>Delete Resource Group</h2>\n";
-			print "You do not have access to delete the selected resource group.\n";
+			$rt = array('status' => 'noaccess',
+			            'title' => _('Delete Resource Group Error'),
+			            'msg' => _('You do not have access to delete the selected resource group.'));
+			sendJSON($rt);
 			return;
 		}
 	}
@@ -1628,101 +1657,98 @@ function confirmDeleteGroup() {
 	$resourcegroups = getResourceGroups();
 
 	if($type == "user") {
-		$title = "Delete User Group";
-		$usemsg = "This group is currently in use.  You cannot delete it until "
-		        . "it is no longer being used.";
-		$question = "Delete the following user group?";
+		$title = _("Delete User Group");
+		$usemsg = wordwrap(_("This group is currently in use. You cannot delete it until it is no longer being used."), 75, "<br>");
+		$question = _("Delete the following user group?");
 		$name = $usergroups[$groupid]["name"];
 		$target = "";
 	}
 	else {
-		$title = "Delete Resource Group";
-		$usemsg = "This group is currently assigned to at least one node in the "
-		        . "privilege tree.  You cannot delete it until it is no longer "
-		        . "in use.";
-		$question = "Delete the following resource group?";
+		if($resourcegroups[$groupid]['name'] == 'computer/newimages' ||
+			$resourcegroups[$groupid]['name'] == 'computer/newvmimages') {
+			$rt = array('status' => 'noaccess',
+			            'title' => _('Delete Resource Group Error'),
+			            'msg' => _('The submitted resource group is a system group that cannot be deleted.'));
+			sendJSON($rt);
+			return;
+		}
+
+		$title = _("Delete Resource Group");
+		$usemsg = wordwrap(_("This group is currently assigned to at least one node in the privilege tree. You cannot delete it until it is no longer in use."), 75, "<br>");
+		$question = _("Delete the following resource group?");
 		list($resourcetype, $name) = 
 			explode('/', $resourcegroups[$groupid]["name"]);
 		$target = "#resources";
 	}
 
 	if(checkForGroupUsage($groupid, $type, $usemsg)) {
-		print "<H2 align=center>$title</H2>\n";
-		print $usemsg;
+		$rt = array('status' => 'inuse',
+		            'title' => $title,
+		            'msg' => $usemsg);
+		sendJSON($rt);
 		return;
 	}
 
-	print "<DIV align=center>\n";
-	print "<H2>$title</H2>\n";
-	print "$question<br><br>\n";
-	print "<TABLE>\n";
+	$cdata = array('type' => $type,
+	               'groupid' => $groupid);
+
+	$cont = addContinuationsEntry('AJsubmitDeleteGroup', $cdata, 3600, 1, 0);
+
+	$rt = array('status' => 'success',
+	            'title' => $title,
+	            'question' => $question,
+	            'cont' => $cont);
+
+	$h = "<TABLE>";
 	if($type == "resource") {
-		print "  <TR>\n";
-		print "    <TH align=right>Type:</TH>\n";
-		print "    <TD>$resourcetype</TD>\n";
-		print "  </TR>\n";
+		$h .= "<TR>";
+		$h .= "<TH align=right>" . _("Type:") . "</TH>";
+		$h .= "<TD>" . _($resourcetype) . "</TD>";
+		$h .= "</TR>";
 	}
-	print "  <TR>\n";
-	print "    <TH align=right>Name:</TH>\n";
-	print "    <TD>$name</TD>\n";
-	print "  </TR>\n";
+	$h .= "<TR>";
+	$h .= "<TH align=right>" . _("Name:") . "</TH>";
+	$h .= "<TD>$name</TD>";
+	$h .= "</TR>";
 	if($type == "resource") {
-		print "  <TR>\n";
-		print "    <TH align=right>Owning User Group:</TH>\n";
-		print "    <TD>" . $resourcegroups[$groupid]["owner"] . "</TD>\n";
-		print "  </TR>\n";
+		$h .= "<TR>";
+		$h .= "<TH align=right>" . _("Owning User Group:") . "</TH>";
+		$h .= "<TD>" . $resourcegroups[$groupid]["owner"] . "</TD>";
+		$h .= "</TR>";
 	}
 	elseif($usergroups[$groupid]['courseroll'] == 1 ||
 	   $usergroups[$groupid]['custom'] == 0) {
-		print "<TR>\n";
-		print "  <TH align=right>Type:</TH>\n";
+		$h .= "<TR>";
+		$h .= "  <TH align=right>" . _("Type:") . "</TH>";
 		if($usergroups[$groupid]['courseroll'] == 1)
-			print "  <TD>Course Roll</TD>\n";
+			$h .= "  <TD>" . _("Course Roll") . "</TD>";
 		elseif($usergroups[$groupid]['custom'] == 0)
-			print "  <TD>Federated</TD>\n";
-		print "</TR>\n";
-		print "<TR>\n";
-		print "  <TD colspan=2><br><strong>Note</strong>: This type of group is ";
-		print "created from external sources<br>and could be recreated from ";
-		print "those sources at any time.<br><br></TD>\n";
-		print "</TR>\n";
+			$h .= "  <TD>" . _("Federated") . "</TD>";
+		$h .= "</TR>";
+		$h .= "<TR>";
+		$h .= "  <TD colspan=2><br><strong>" . _("Note") . "</strong>:";
+		$h .= wordwrap(_("This type of group is created from external sources and could be recreated from those sources at any time."), 75, "<br>");
+		$h .= "</TD>";
+		$h .= "</TR>";
 	}
-	print "</TABLE>\n";
-	print "<TABLE>\n";
-	print "  <TR valign=top>\n";
-	print "    <TD>\n";
-	print "      <FORM action=\"" . BASEURL . SCRIPT . "$target\" method=post>\n";
-	$cdata = array('groupid' => $groupid,
-	               'type' => $type);
-	$cont = addContinuationsEntry('submitDeleteGroup', $cdata);
-	print "      <INPUT type=hidden name=continuation value=\"$cont\">\n";
-	print "      <INPUT type=submit value=Submit>\n";
-	print "      </FORM>\n";
-	print "    </TD>\n";
-	print "    <TD>\n";
-	print "      <FORM action=\"" . BASEURL . SCRIPT . "\" method=post>\n";
-	print "      <INPUT type=hidden name=mode value=viewGroups>\n";
-	print "      <INPUT type=submit value=Cancel>\n";
-	print "      </FORM>\n";
-	print "    </TD>\n";
-	print "  </TR>\n";
-	print "</TABLE>\n";
-	print "</DIV>\n";
+	$h .= "</TABLE>";
+	$rt['content'] = $h;
+	sendJSON($rt);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 ///
-/// \fn submitDeleteGroup()
+/// \fn AJsubmitDeleteGroup()
 ///
-/// \brief deletes an group from the database and notifies the user
+/// \brief deletes a group from the database and notifies the user
 ///
 ////////////////////////////////////////////////////////////////////////////////
-function submitDeleteGroup() {
+function AJsubmitDeleteGroup() {
 	$groupid = getContinuationVar("groupid");
 	$type = getContinuationVar("type");
 	if($type == "user") {
 		$query = "UPDATE blockRequest "
-		       . "SET groupid = 0 "
+		       . "SET groupid = NULL "
 		       . "WHERE groupid = $groupid";
 		doQuery($query);
 		$table = "usergroup";
@@ -1733,7 +1759,10 @@ function submitDeleteGroup() {
 			 . "WHERE id = $groupid";
 	doQuery($query, 315);
 	clearPrivCache();
-	viewGroups();
+	$data = array('status' => 'success',
+	              'type' => $type,
+	              'id' => $groupid);
+	sendJSON($data);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
