@@ -82,16 +82,16 @@ class Schedule extends Resource {
 
 		$h .= "<div style=\"text-align: center;\">\n";
 		# name
-		$errmsg = _("Name cannot contain single (') or double (&quot;) quotes, less than (&lt;), or greater than (&gt;) and can be from 2 to 30 characters long");
-		$h .= labeledFormItem('name', _('Name'), 'text', '^([A-Za-z0-9-!@#$%^&\*\(\)_=\+\[\]{}\\\|:;,\./\?~` ]){2,30}$',
+		$errmsg = i("Name cannot contain single (') or double (&quot;) quotes, less than (&lt;), or greater than (&gt;) and can be from 2 to 30 characters long");
+		$h .= labeledFormItem('name', i('Name'), 'text', '^([A-Za-z0-9-!@#$%^&\*\(\)_=\+\[\]{}\\\|:;,\./\?~` ]){2,30}$',
 		                      1, '', $errmsg, '', '', '200px'); 
 		# owner
 		$extra = array('onKeyPress' => 'setOwnerChecking');
-		$h .= labeledFormItem('owner', _('Owner'), 'text', '', 1,
-		                      "{$user['unityid']}@{$user['affiliation']}", _('Unknown user'),
+		$h .= labeledFormItem('owner', i('Owner'), 'text', '', 1,
+		                      "{$user['unityid']}@{$user['affiliation']}", i('Unknown user'),
 		                      'checkOwner', $extra, '200px');
-		#$h .= labeledFormItem('owner', _('Owner'), 'text', '{$user['unityid']}@{$user['affiliation']}',
-		#                      1, '', _('Unknown user'), 'checkOwner', 'onKeyPress', 'setOwnerChecking');
+		#$h .= labeledFormItem('owner', i('Owner'), 'text', '{$user['unityid']}@{$user['affiliation']}',
+		#                      1, '', i('Unknown user'), 'checkOwner', 'onKeyPress', 'setOwnerChecking');
 		$cont = addContinuationsEntry('AJvalidateUserid');
 		$h .= "<input type=\"hidden\" id=\"valuseridcont\" value=\"$cont\">\n";
 
@@ -106,10 +106,13 @@ class Schedule extends Resource {
 		$h .= selectInputAutoDijitHTML('startday', $days, 'startday');
 		$h .= "<input type=\"text\" id=\"starttime\" dojoType=\"dijit.form.TimeTextBox\" ";
 		$h .= "required=\"true\" value=\"T00:00:00\"/>\n";
+		$h .= "<small>(" . date('T') . ")</small>\n";
+		$h .= "&nbsp;|&nbsp;&nbsp;";
 		$h .= "End:";
 		$h .= selectInputAutoDijitHTML('endday', $days, 'endday');
 		$h .= "<input type=\"text\" id=\"endtime\" dojoType=\"dijit.form.TimeTextBox\" ";
 		$h .= "required=\"true\" value=\"T00:00:00\" />\n";
+		$h .= "<small>(" . date('T') . ")</small>\n";
 		$h .= dijitButton('addTimeBtn', "Add", "addTime();");
 		$h .= "</div>\n"; # text-align: center
 		$h .= "<div dojoType=\"dojo.data.ItemFileWriteStore\" jsId=\"scheduleStore\" ";
@@ -131,7 +134,7 @@ class Schedule extends Resource {
 		$h .= "<div id=\"addeditdlgerrmsg\" class=\"nperrormsg\"></div>\n";
 		$h .= "<div id=\"editdlgbtns\" align=\"center\">\n";
 		$h .= dijitButton('addeditbtn', "Confirm", "saveResource();");
-		$h .= dijitButton('', "Cancel", "addEditDlgHide();");
+		$h .= dijitButton('', _("Cancel"), "addEditDlgHide();");
 		$h .= "</div>\n"; # editdlgbtns
 		$h .= "</div>\n"; # addeditdlg
 
@@ -159,6 +162,8 @@ class Schedule extends Resource {
 		$h .= "</div>\n"; # btn div
 		$h .= "</div>\n"; # groupdlg
 
+		$h .= "<input type=\"hidden\" id=\"timezonevalue\" value=\"" . date('T') . "\">\n";
+
 		return $h;
 	}
 
@@ -166,6 +171,8 @@ class Schedule extends Resource {
 	///
 	/// \fn checkResourceInUse($rscid)
 	///
+	/// \param $rscid - id of schedule
+	///
 	/// \return empty string if not being used; string of where resource is
 	/// being used if being used
 	///
