@@ -30,7 +30,7 @@ $actions["entry"] = array('main',
                           'blockAllocations',
                           'userpreferences',
                           'viewGroups',
-                          'serverProfiles',
+                          #'serverProfiles',
                           'pickTimeTable',
                           'viewNodes',
                           'userLookup',
@@ -56,10 +56,15 @@ $actions["entry"] = array('main',
                           'computer',
                           'managementnode',
                           'schedule',
+                          'addomain',
                           'RESTresourceBasic',
                           'RESTresourceDetail',
                           #'testDojoREST',
                           'siteconfig',
+                          'newOneClick',
+                          'AJsetTZoffset',
+                          'changeLocale',
+                          'checkMissingWebSecretKeys',
 );
 
 $noHTMLwrappers = array('sendRDPfile',
@@ -75,6 +80,10 @@ $noHTMLwrappers = array('sendRDPfile',
                         'AJsubmitAddChildNode',
                         'AJsubmitDeleteNode',
                         'AJsubmitRenameNode',
+                        'AJmoveNode',
+                        'AJsubmitMoveNode',
+                        'AJrevertMoveNode',
+                        'AJrefreshNodeDropData',
                         'AJupdateWaitTime',
                         'AJviewRequests',
                         'AJnewRequest',
@@ -132,7 +141,7 @@ $noHTMLwrappers = array('sendRDPfile',
                         'AJpermSelectUserGroup',
                         'AJcopyUserGroupPrivs',
                         'AJsaveUserGroupPrivs',
-                        'AJsaveServerProfile',
+                        /*'AJsaveServerProfile',
                         'AJserverProfileData',
                         'AJdelServerProfile',
                         'jsonProfileGroupingGroups',
@@ -142,7 +151,7 @@ $noHTMLwrappers = array('sendRDPfile',
                         'AJaddProfileToGroup',
                         'AJremProfileFromGroup',
                         'AJserverProfileStoreData',
-                        'AJfetchRouterDNS',
+                        'AJfetchRouterDNS',*/
                         'AJconfirmDeleteRequest',
                         'AJsubmitDeleteRequest',
                         'AJconfirmRemoveRequest',
@@ -189,6 +198,8 @@ $noHTMLwrappers = array('sendRDPfile',
                         'AJreloadComputers',
                         'AJsubmitReloadComputers',
                         'AJdeleteComputers',
+                        'AJshowReservations',
+                        'AJshowReservationHistory',
                         'AJsubmitDeleteComputers',
                         'AJcompScheduleChange',
                         'AJsubmitCompScheduleChange',
@@ -208,6 +219,14 @@ $noHTMLwrappers = array('sendRDPfile',
                         'AJdeleteAffiliationSetting',
                         'AJaddAffiliationSetting',
                         'AJpreviewClickThrough',
+                        'AJdeleteMultiSetting',
+                        'AJaddConfigMultiVal',
+                        'AJsaveMessages',
+                        'AJdeleteMessages',
+                        'AJvalidateMessagesPoll',
+                        'AJsetTZoffset',
+                        'AJconfirmDeleteGroup',
+                        'AJsubmitDeleteGroup',
 );
 
 # main
@@ -247,6 +266,7 @@ $actions['pages']['selectTimeTable'] = "reservations";
 $actions['pages']['AJshowRequestSuggestedTimes'] = "reservations";
 $actions['pages']['AJrebootRequest'] = "reservations";
 $actions['pages']['AJreinstallRequest'] = "reservations";
+$actions['pages']['AJsetImageProduction'] = "reservations";
 $actions['pages']['AJsubmitSetImageProduction'] = "reservations";
 $actions['pages']['AJshowReinstallRequest'] = "reservations";
 $actions['pages']['viewRequests'] = "reservations";
@@ -332,8 +352,8 @@ $actions['mode']['submitEditGroup'] = "submitEditGroup";
 $actions['mode']['confirmAddGroup'] = "confirmEditOrAddGroup";
 $actions['args']['confirmAddGroup'] = 1;
 $actions['mode']['submitAddGroup'] = "submitAddGroup";
-$actions['mode']['confirmDeleteGroup'] = "confirmDeleteGroup";
-$actions['mode']['submitDeleteGroup'] = "submitDeleteGroup";
+$actions['mode']['AJconfirmDeleteGroup'] = "AJconfirmDeleteGroup";
+$actions['mode']['AJsubmitDeleteGroup'] = "AJsubmitDeleteGroup";
 $actions['mode']['addGroupUser'] = "addGroupUser";
 $actions['mode']['deleteGroupUser'] = "deleteGroupUser";
 $actions['mode']['jsonGetGroupInfo'] = "jsonGetGroupInfo";
@@ -346,8 +366,8 @@ $actions['pages']['confirmEditGroup'] = "manageGroups";
 $actions['pages']['submitEditGroup'] = "manageGroups";
 $actions['pages']['confirmAddGroup'] = "manageGroups";
 $actions['pages']['submitAddGroup'] = "manageGroups";
-$actions['pages']['confirmDeleteGroup'] = "manageGroups";
-$actions['pages']['submitDeleteGroup'] = "manageGroups";
+$actions['pages']['AJconfirmDeleteGroup'] = "manageGroups";
+$actions['pages']['AJsubmitDeleteGroup'] = "manageGroups";
 $actions['pages']['addGroupUser'] = "manageGroups";
 $actions['pages']['deleteGroupUser'] = "manageGroups";
 $actions['pages']['jsonGetGroupInfo'] = "manageGroups";
@@ -355,7 +375,7 @@ $actions['pages']['jsonUserGroupStore'] = "manageGroups";
 $actions['pages']['jsonResourceGroupStore'] = "manageGroups";
 
 # server profiles
-$actions['mode']['serverProfiles'] = "serverProfiles"; # entry
+/*$actions['mode']['serverProfiles'] = "serverProfiles"; # entry
 $actions['mode']['AJsaveServerProfile'] = "AJsaveServerProfile";
 $actions['mode']['AJserverProfileData'] = "AJserverProfileData";
 $actions['mode']['AJdelServerProfile'] = "AJdelServerProfile";
@@ -378,7 +398,7 @@ $actions['pages']['AJremGroupFromProfile'] = "serverProfiles";
 $actions['pages']['AJaddProfileToGroup'] = "serverProfiles";
 $actions['pages']['AJremProfileFromGroup'] = "serverProfiles";
 $actions['pages']['AJserverProfileStoreData'] = "serverProfiles";
-$actions['pages']['AJfetchRouterDNS'] = "serverProfiles";
+$actions['pages']['AJfetchRouterDNS'] = "serverProfiles";*/
 
 # time table
 # TODO a few of these belong to new reservation
@@ -403,6 +423,10 @@ $actions['mode']['AJsubmitAddChildNode'] = "AJsubmitAddChildNode";
 $actions['mode']['submitDeleteNode'] = "submitDeleteNode";
 $actions['mode']['AJsubmitDeleteNode'] = "AJsubmitDeleteNode";
 $actions['mode']['AJsubmitRenameNode'] = "AJsubmitRenameNode";
+$actions['mode']['AJmoveNode'] = "AJmoveNode";
+$actions['mode']['AJsubmitMoveNode'] = "AJsubmitMoveNode";
+$actions['mode']['AJrevertMoveNode'] = "AJrevertMoveNode";
+$actions['mode']['AJrefreshNodeDropData'] = "AJrefreshNodeDropData";
 $actions['mode']['viewNodePrivs'] = "viewNodePrivs";
 $actions['mode']['selectNode'] = "selectNode";
 $actions['mode']['changeUserPrivs'] = "changeUserPrivs";
@@ -432,6 +456,10 @@ $actions['pages']['AJsubmitAddChildNode'] = "privileges";
 $actions['pages']['submitDeleteNode'] = "privileges";
 $actions['pages']['AJsubmitDeleteNode'] = "privileges";
 $actions['pages']['AJsubmitRenameNode'] = "privileges";
+$actions['pages']['AJmoveNode'] = "privileges";
+$actions['pages']['AJsubmitMoveNode'] = "privileges";
+$actions['pages']['AJrevertMoveNode'] = "privileges";
+$actions['pages']['AJrefreshNodeDropData'] = "privileges";
 $actions['pages']['viewNodePrivs'] = "privileges";
 $actions['pages']['selectNode'] = "privileges";
 $actions['pages']['changeUserPrivs'] = "privileges";
@@ -536,11 +564,21 @@ $actions['mode']['AJupdateTimeSource'] = "AJupdateTimeSource";
 $actions['mode']['AJaddAffiliationSetting'] = "AJaddAffiliationSetting";
 $actions['mode']['AJupdateAllSettings'] = "AJupdateAllSettings";
 $actions['mode']['AJdeleteAffiliationSetting'] = "AJdeleteAffiliationSetting";
+$actions['mode']['AJaddConfigMultiVal'] = "AJaddConfigMultiVal";
+$actions['mode']['AJdeleteMultiSetting'] = "AJdeleteMultiSetting";
+$actions['mode']['AJsaveMessages'] = "AJsaveMessages";
+$actions['mode']['AJdeleteMessages'] = "AJdeleteMessages";
+$actions['mode']['AJvalidateMessagesPoll'] = "AJvalidateMessagesPoll";
 $actions['pages']['siteconfig'] = "siteconfig";
 $actions['pages']['AJupdateTimeSource'] = "siteconfig";
 $actions['pages']['AJaddAffiliationSetting'] = "siteconfig";
 $actions['pages']['AJupdateAllSettings'] = "siteconfig";
 $actions['pages']['AJdeleteAffiliationSetting'] = "siteconfig";
+$actions['pages']['AJaddConfigMultiVal'] = "siteconfig";
+$actions['pages']['AJdeleteMultiSetting'] = "siteconfig";
+$actions['pages']['AJsaveMessages'] = "siteconfig";
+$actions['pages']['AJdeleteMessages'] = "siteconfig";
+$actions['pages']['AJvalidateMessagesPoll'] = "siteconfig";
 $actions['classmapping']['timevariable'] = 'siteconfig';
 $actions['classmapping']['connectedusercheck'] = 'siteconfig';
 $actions['classmapping']['acknowledge'] = 'siteconfig';
@@ -554,6 +592,15 @@ $actions['classmapping']['generalendnotice2'] = 'siteconfig';
 $actions['classmapping']['userpasswordlength'] = 'siteconfig';
 $actions['classmapping']['userpasswordspecialchar'] = 'siteconfig';
 $actions['classmapping']['natportrange'] = 'siteconfig';
+$actions['classmapping']['nfsmounts'] = 'siteconfig';
+$actions['classmapping']['affiliations'] = 'siteconfig';
+$actions['classmapping']['messages'] = 'siteconfig';
+$actions['classmapping']['affilhelpaddress'] = 'siteconfig';
+$actions['classmapping']['affilwebaddress'] = 'siteconfig';
+$actions['classmapping']['affilkmsserver'] = 'siteconfig';
+$actions['classmapping']['affiltheme'] = 'siteconfig';
+$actions['classmapping']['affilshibonly'] = 'siteconfig';
+$actions['classmapping']['affilshibname'] = 'siteconfig';
 
 # resource
 $actions['mode']['resource'] = "resource";
@@ -567,6 +614,8 @@ $actions['mode']['managementnode'] = "resource";
 $actions['args']['managementnode'] = 'managementnode';
 $actions['mode']['schedule'] = "resource";
 $actions['args']['schedule'] = 'schedule';
+$actions['mode']['addomain'] = "resource";
+$actions['args']['addomain'] = 'addomain';
 $actions['mode']['viewResources'] = "viewResources";
 $actions['mode']['jsonResourceStore'] = "jsonResourceStore";
 $actions['mode']['AJpromptToggleDeleteResource'] = "AJpromptToggleDeleteResource";
@@ -597,6 +646,8 @@ $actions['mode']['AJcanceltovmhostinuse'] = "AJcanceltovmhostinuse";
 $actions['mode']['AJreloadComputers'] = "AJreloadComputers";
 $actions['mode']['AJsubmitReloadComputers'] = "AJsubmitReloadComputers";
 $actions['mode']['AJdeleteComputers'] = "AJdeleteComputers";
+$actions['mode']['AJshowReservations'] = "AJshowReservations";
+$actions['mode']['AJshowReservationHistory'] = "AJshowReservationHistory";
 $actions['mode']['AJsubmitDeleteComputers'] = "AJsubmitDeleteComputers";
 $actions['mode']['AJcompScheduleChange'] = "AJcompScheduleChange";
 $actions['mode']['AJsubmitCompScheduleChange'] = "AJsubmitCompScheduleChange";
@@ -625,6 +676,7 @@ $actions['pages']['image'] = "image";
 $actions['pages']['computer'] = "computer";
 $actions['pages']['managementnode'] = "managementnode";
 $actions['pages']['schedule'] = "schedule";
+$actions['pages']['addomain'] = "addomain";
 $actions['pages']['viewResources'] = "resource";
 $actions['pages']['jsonResourceStore'] = "resource";
 $actions['pages']['AJpromptToggleDeleteResource'] = "resource";
@@ -655,6 +707,8 @@ $actions['pages']['AJcanceltovmhostinuse'] = "resource";
 $actions['pages']['AJreloadComputers'] = "resource";
 $actions['pages']['AJsubmitReloadComputers'] = "resource";
 $actions['pages']['AJdeleteComputers'] = "resource";
+$actions['pages']['AJshowReservations'] = "resource";
+$actions['pages']['AJshowReservationHistory'] = "resource";
 $actions['pages']['AJsubmitDeleteComputers'] = "resource";
 $actions['pages']['AJcompScheduleChange'] = "resource";
 $actions['pages']['AJsubmitCompScheduleChange'] = "resource";
@@ -698,6 +752,8 @@ $actions['mode']['clearCache'] = "clearPrivCache";
 $actions['mode']['errorrpt'] = "errorrpt";
 $actions['mode']['AJvalidateUserid'] = "AJvalidateUserid";
 $actions['mode']['changeLocale'] = "changeLocale";
+$actions['mode']['AJsetTZoffset'] = "AJsetTZoffset";
+$actions['mode']['checkMissingWebSecretKeys'] = "checkMissingWebSecretKeys";
 $actions['pages']['continuationsError'] = "misc";
 $actions['pages']['clearCache'] = "misc";
 $actions['pages']['errorrpt'] = "misc";
@@ -705,5 +761,18 @@ $actions['pages']['logout'] = "misc";
 $actions['pages']['shiblogout'] = "misc";
 $actions['pages']['AJvalidateUserid'] = "misc";
 $actions['pages']['changeLocale'] = "misc";
+$actions['pages']['AJsetTZoffset'] = "misc";
+$actions['pages']['checkMissingWebSecretKeys'] = "misc";
 
+# OneClicks (VCL go)
+$actions['mode']['newOneClick'] = "newOneClick";
+$actions['mode']['submitOneClick'] = "submitOneClick";
+$actions['mode']['deleteOneClick'] = "deleteOneClick";
+$actions['mode']['editOneClick'] = "editOneClick";
+$actions['mode']['submitEditOneClick']= "submitEditOneClick";
+$actions['pages']['newOneClick'] = "oneClicks";
+$actions['pages']['submitOneClick'] = "oneClicks";
+$actions['pages']['deleteOneClick'] = "oneClicks";
+$actions['pages']['editOneClick'] = "oneClicks";
+$actions['pages']['submitEditOneClick'] = "oneClicks";
 ?>
