@@ -52,10 +52,10 @@ function userpreferences() {
 			$data["resolution"] = $user["width"] . "x" . $user["height"];
 	}
 
-	print _("<H2 align=center>User Preferences</H2>\n");
+	print i("<H2 align=center>User Preferences</H2>\n");
 	print "<div align=center id=status class=visible>\n";
 	if($mode == "submituserprefs") {
-		print "<font color=green>" . _("User preferences successfully updated") . "</font><br>\n";
+		print "<font color=green>" . i("User preferences successfully updated") . "</font><br>\n";
 	}
 	print "</div>\n";
 	print "<table summary=\"\">\n";
@@ -68,35 +68,35 @@ function userpreferences() {
 	   $user['affiliation'] == 'Local') {
 		$showpersonal = 1;
 		print "      <li><a href=#personal onclick=\"";
-		print "show('personal'); return false;\">" . _("Personal Information") . "</a>";
+		print "show('personal'); return false;\">" . i("Personal Information") . "</a>";
 		print "</li>\n";
 	}
 	print "      <li><a href=#rdpfile onclick=\"";
-	print "show('rdpfile'); return false;\">" . _("RDP Preferences") . "</a>";
+	print "show('rdpfile'); return false;\">" . i("RDP Preferences") . "</a>";
 	print "</li>\n";
 	print "      <li><a href=#uiprefs onclick=\"javascript:show('uiprefs'); ";
-	print "return false\">" . _("General Preferences") . "</a></li>\n";
+	print "return false\">" . i("General Preferences") . "</a></li>\n";
 	print "      </ul>\n";
 	print "      </div>\n";
 	print "    </TD>\n";
-	print "    <TD rowspan=2 width=50px></TD>\n";
-	print "    <TD rowspan=2>\n";
+	print "    <TD rowspan=2 style=\"width: 5em;\"></TD>\n";
+	print "    <TD rowspan=2 id=\"uipreffieldsets\">\n";
 	if($showpersonal) {
 		print "      <fieldset id=personal class=shown>\n";
-		print "      <legend>" . _("Personal") . "</legend>\n";
+		print "      <legend>" . i("Personal") . "</legend>\n";
 		print "      <FORM action=\"" . BASEURL . SCRIPT . "\" method=post>\n";
 		print "      <table summary=\"displays your personal information\">\n";
 		$showsubmit = 0;
 		if(! empty($user['firstname'])) {
 			print "        <TR>\n";
-			print "          <TH align=right>" . _("First Name:") . "<a href=#updateinfo>*</a></TH>\n";
+			print "          <TH align=right>" . i("First Name:") . "<a href=#updateinfo>*</a></TH>\n";
 			print "          <TD>" . $user["firstname"] . "</TD>\n";
 			print "          <TD></TD>\n";
 			print "        </TR>\n";
 		}
 		if(! empty($user['lastname'])) {
 			print "        <TR>\n";
-			print "          <TH align=right>" . _("Last Name:") . "<a href=#updateinfo>*</a></TH>\n";
+			print "          <TH align=right>" . i("Last Name:") . "<a href=#updateinfo>*</a></TH>\n";
 			print "          <TD>" . $user["lastname"] . "</TD>\n";
 			print "          <TD></TD>\n";
 			print "        </TR>\n";
@@ -104,7 +104,7 @@ function userpreferences() {
 		# preferred name is stored locally; allow setting preferred name if a firstname is defined
 		if(! empty($user['firstname'])) {
 			print "        <TR>\n";
-			print "          <TH align=right>" . _("Preferred Name:") . "</TH>\n";
+			print "          <TH align=right>" . i("Preferred Name:") . "</TH>\n";
 			print "          <TD><label class=hidden for=preferredname>Preferred Name</label>\n";
 			print "              <INPUT type=text name=preferredname maxlength=100 ";
 			print "size=15 value=\"" . $data["preferredname"] . "\"></TD>\n";
@@ -116,17 +116,17 @@ function userpreferences() {
 		}
 		if(! empty($user['email'])) {
 			print "        <TR>\n";
-			print "          <TH align=right>" . _("Email Address:") . "<a href=#updateinfo>*</a></TH>\n";
+			print "          <TH align=right>" . i("Email Address:") . "<a href=#updateinfo>*</a></TH>\n";
 			print "          <TD>" . $user["email"] . "</TD>\n";
 			print "          <TD></TD>\n";
 			print "        </TR>\n";
 		}
 		if($user['affiliation'] == 'Local') {
 			print "        <TR>\n";
-			print "          <TD colspan=3 align=center><h3>" . _("Change Password") . "</h3></TD>\n";
+			print "          <TD colspan=3 align=center><h3>" . i("Change Password") . "</h3></TD>\n";
 			print "        </TR>\n";
 			print "        <TR>\n";
-			print "          <TH align=right>" . _("Current Password:") . "</TH>\n";
+			print "          <TH align=right>" . i("Current Password:") . "</TH>\n";
 			print "          <TD>\n";
 			print "            <label class=hidden for=currentpassword>Current Password</label>\n";
 			print "            <INPUT type=password name=currentpassword maxlength=100 size=15>\n";
@@ -136,7 +136,7 @@ function userpreferences() {
 			print "</TD>\n";
 			print "        </TR>\n";
 			print "        <TR>\n";
-			print "          <TH align=right>" . _("New Password:") . "</TH>\n";
+			print "          <TH align=right>" . i("New Password:") . "</TH>\n";
 			print "          <TD>\n";
 			print "            <label class=hidden for=newpassword>New Password</label>\n";
 			print "            <INPUT type=password name=newpassword maxlength=100 ";
@@ -145,7 +145,7 @@ function userpreferences() {
 			print "          <TD></TD>\n";
 			print "        </TR>\n";
 			print "        <TR>\n";
-			print "          <TH align=right>" . _("Confirm Password:") . "</TH>\n";
+			print "          <TH align=right>" . i("Confirm Password:") . "</TH>\n";
 			print "          <TD>\n";
 			print "            <label class=hidden for=confirmpassword>Confirm Password</label>\n";
 			print "            <INPUT type=password name=confirmpassword maxlength=100 ";
@@ -164,7 +164,7 @@ function userpreferences() {
 			$cont = addContinuationsEntry('confirmpersonalprefs', array(), SECINDAY, 1, 1, 1);
 			print "      <INPUT type=hidden name=continuation value=\"$cont\">\n";
 			print "      <div align=center>\n";
-			print "      <INPUT type=submit value=\"" . _("Submit Changes") . "\">\n";
+			print "      <INPUT type=submit value=\"" . i("Submit Changes") . "\">\n";
 			print "      </div>\n";
 		}
 		print "      </FORM>\n";
@@ -172,18 +172,18 @@ function userpreferences() {
 	}
 
 	print "      <fieldset id=rdpfile class=shown>\n";
-	print "      <legend>" . _("RDP") . "</legend>\n";
+	print "      <legend>" . i("RDP") . "</legend>\n";
 	print "      <FORM action=\"" . BASEURL . SCRIPT . "\" method=post>\n";
 	print "      <table summary=\"lists adjustable preferences for the RDP ";
 	print "file that is sent when you click the Get RDP File button on the ";
 	print "Connect! page and the port on which RDP is listening\">\n";
 	print "        <TR>\n";
 	print "          <TD colspan=3><div style=\"width: 300px;\"><small>";
-	print _("Try decreasing <em>Resolution</em> or <em>Color Depth</em> to speed up your connection if things seem slow when connected to a remote computer.");
+	print i("Try decreasing <em>Resolution</em> or <em>Color Depth</em> to speed up your connection if things seem slow when connected to a remote computer.");
 	print "</div></small></TD>\n";
 	print "        </TR>\n";
 	print "        <TR>\n";
-	print "          <TH align=right>" . _("Resolution:") . "</TH>\n";
+	print "          <TH align=right>" . i("Resolution:") . "</TH>\n";
 	$resolutionArray = array("Full Screen" => "Full Screen",
 	                         "1920x1440" => "1920x1440",
 	                         "1600x1200" => "1600x1200",
@@ -204,7 +204,7 @@ function userpreferences() {
 	print "          <TD></TD>\n";
 	print "        </TR>\n";
 	print "        <TR>\n";
-	print "          <TH align=right>" . _("Color Depth:") . "</TH>\n";
+	print "          <TH align=right>" . i("Color Depth:") . "</TH>\n";
 	print "          <TD>\n";
 	$colordepth = array("8" => "8", "16" => "16", "24" => "24", "32" => "32");
 	printSelectInput("bpp", $colordepth, $data["bpp"]);
@@ -212,37 +212,37 @@ function userpreferences() {
 	print "          <TD></TD>\n";
 	print "        </TR>\n";
 	print "        <TR>\n";
-	print "          <TH align=right>" . _("Audio:") . "</TH>\n";
+	print "          <TH align=right>" . i("Audio:") . "</TH>\n";
 	print "          <TD>\n";
-	$audio = array("none" => _("None"), "local" => _("Use my speakers"));
+	$audio = array("none" => i("None"), "local" => i("Use my speakers"));
 	printSelectInput("audiomode", $audio, $data["audiomode"]);
 	print "          </TD>\n";
 	print "          <TD></TD>\n";
 	print "        </TR>\n";
 	print "        <TR>\n";
-	print "          <TH align=right>" . _("Map Local Drives:") . "</TH>\n";
+	print "          <TH align=right>" . i("Map Local Drives:") . "</TH>\n";
 	print "          <TD>\n";
-	$yesno = array(1 => _("Yes"), 0 => _("No"));
+	$yesno = array(1 => i("Yes"), 0 => i("No"));
 	printSelectInput("mapdrives", $yesno, $data["mapdrives"]);
 	print "          </TD>\n";
 	print "          <TD></TD>\n";
 	print "        </TR>\n";
 	print "        <TR>\n";
-	print "          <TH align=right>" . _("Map Local Printers:") . "</TH>\n";
+	print "          <TH align=right>" . i("Map Local Printers:") . "</TH>\n";
 	print "          <TD>\n";
 	printSelectInput("mapprinters", $yesno, $data["mapprinters"]);
 	print "          </TD>\n";
 	print "          <TD></TD>\n";
 	print "        </TR>\n";
 	print "        <TR>\n";
-	print "          <TH align=right>" . _("Map Local Serial Ports:") . "</TH>\n";
+	print "          <TH align=right>" . i("Map Local Serial Ports:") . "</TH>\n";
 	print "          <TD>\n";
 	printSelectInput("mapserial", $yesno, $data["mapserial"]);
 	print "          </TD>\n";
 	print "          <TD></TD>\n";
 	print "        </TR>\n";
 	print "        <TR>\n";
-	print "          <TH align=right>" . _("RDP Port") . ":</TH>\n";
+	print "          <TH align=right>" . i("RDP Port") . ":</TH>\n";
 	print "          <TD>\n";
 	print "            <INPUT type=text name=rdpport maxlength=5 ";
 	print "size=8 value=\"" . $data["rdpport"] . "\"></TD>\n";
@@ -255,14 +255,14 @@ function userpreferences() {
 	$cont = addContinuationsEntry('confirmrdpprefs', array(), SECINDAY, 1, 1, 1);
 	print "      <INPUT type=hidden name=continuation value=\"$cont\">\n";
 	print "      <div align=center>\n";
-	print "      <INPUT type=submit value=\"" . _("Submit Changes") . "\">\n";
+	print "      <INPUT type=submit value=\"" . i("Submit Changes") . "\">\n";
 	print "      </div>\n";
 	print "      </FORM>\n";
 	print "      </fieldset>\n";
 
 	print "      <div id=uiprefs class=shown>\n";
 	print "      <fieldset>\n";
-	print "      <legend>" . _("General Preferences") . "</legend>\n";
+	print "      <legend>" . i("General Preferences") . "</legend>\n";
 	print "      <FORM action=\"" . BASEURL . SCRIPT . "\" method=post ";
 	print "onsubmit=\"return validatePublicKeys();\">\n";
 	$cdata = array();
@@ -274,12 +274,12 @@ function userpreferences() {
 		$selected['affiliation'] = 'checked';
 		$selected['allgroups'] = '';
 	}
-	print "      <p>" . _("View User Groups:") . "<br>\n";
+	print "      <p>" . i("View User Groups:") . "<br>\n";
 	print "      <INPUT type=radio id=r1 name=groupview value=affiliation ";
-	print "{$selected['affiliation']}" . "><label for=r1>" . _("matching my affiliation");
+	print "{$selected['affiliation']}" . "><label for=r1>" . i("matching my affiliation");
 	print "</label><br>\n";
 	print "      <INPUT type=radio id=r2 name=groupview value=allgroups ";
-	print "{$selected['allgroups']}" . "><label for=r2>" . _("from all affiliations");
+	print "{$selected['allgroups']}" . "><label for=r2>" . i("from all affiliations");
 	print "</label></p>\n";
 	if($user['emailnotices']) {
 		$selected['enabled'] = 'checked';
@@ -289,12 +289,12 @@ function userpreferences() {
 		$selected['enabled'] = '';
 		$selected['disabled'] = 'checked';
 	}
-	print "      <p>" . _("Send email notifications about reservations:") . "<br>\n";
+	print "      <p>" . i("Send email notifications about reservations:") . "<br>\n";
 	print "      <INPUT type=radio id=r3 name=emailnotify value=2 ";
-	print "{$selected['enabled']}" . "><label for=r3>" . _("Enabled");
+	print "{$selected['enabled']}" . "><label for=r3>" . i("Enabled");
 	print "</label><br>\n";
 	print "      <INPUT type=radio id=r4 name=emailnotify value=1 ";
-	print "{$selected['disabled']}" . "><label for=r4>" . _("Disabled");
+	print "{$selected['disabled']}" . "><label for=r4>" . i("Disabled");
 	print "</label></p>\n";
 
 	###########################
@@ -316,32 +316,32 @@ function userpreferences() {
 		$selected['enabled'] = '';
 		$selected['disabled'] = 'checked';
 	}
-	print "      <p>" . _("Use public key authentication for SSH logins:") . "<br>\n";
+	print "      <p>" . i("Use public key authentication for SSH logins:") . "<br>\n";
 	print "      <INPUT type=radio id=r5 name=pubkeyauth value=2 ";
 	print "{$selected['enabled']} onclick=\"togglePubKeys(1);\"><label for=r5>";
-	print _("Enabled") .  "</label><br>\n";
+	print i("Enabled") .  "</label><br>\n";
 	print "      <INPUT type=radio id=r6 name=pubkeyauth value=1 ";
 	print "{$selected['disabled']} onclick=\"togglePubKeys(0);\"><label for=r6>";
-	print _("Disabled") . "</label><br><br>\n";
-	print "      " . _("Public keys:") . "<br>\n";
+	print i("Disabled") . "</label><br><br>\n";
+	print "      " . i("Public keys:") . "<br>\n";
 	print "      <div style=\"width: 300px;\" id=\"pubkeyerr\" ";
 	print "class=\"hidden\">";
 	print "<font color=\"red\"><em>\n      ";
-	print _("Public keys can only contain letters, numbers, spaces, and these characters: + / @ . =");
+	print i("Public keys can only contain letters, numbers, spaces, and these characters: + / @ . =");
 	print "</em></font></div>\n";
 	print "      <textarea id=\"pubkeys\" dojoType=\"dijit.form.Textarea\" ";
 	print "name=\"pubkeys\" style=\"width: 27em;\"";
 	if(! $user['usepublickeys'])
 		print " disabled=\"disabled\"";
 	print ">{$user['sshpublickeys']}</textarea><br><br>\n";
-	print "<strong>" . _("NOTE:") . "</strong> ";
-	$h = "      " . _("Images using network storage (such as AFS) may not work well with public key authentication. In some cases, you may still be prompted for a password. In other cases, you may need to run additional commands after logging in to gain access to the network storage.");
+	print "<strong>" . i("NOTE:") . "</strong> ";
+	$h = "      " . i("Images using network storage (such as AFS) may not work well with public key authentication. In some cases, you may still be prompted for a password. In other cases, you may need to run additional commands after logging in to gain access to the network storage.");
 	print preg_replace("/(.{1,55}([ \n]|$))/", '\1<br>', $h) . "\n";
 	print "      </p>\n";
 
 	$cont = addContinuationsEntry('submitgeneralprefs', $cdata, SECINDAY, 1, 0);
 	print "      <INPUT type=hidden name=continuation value=\"$cont\">\n";
-	print "      <INPUT type=submit value=\"" . _("Submit General Preferences") . "\">\n";
+	print "      <INPUT type=submit value=\"" . i("Submit General Preferences") . "\">\n";
 	print "      </FORM>\n";
 	print "      </fieldset>\n";
 	print "      </div>\n";
@@ -371,68 +371,68 @@ function confirmUserPrefs($type) {
 	}
 
 	if($data["audiomode"] == "none")
-		$audio = _("None");
+		$audio = i("None");
 	else
-		$audio = _("Use my speakers");
+		$audio = i("Use my speakers");
 	if($data["mapdrives"] == 0)
-		$drives = _("No");
+		$drives = i("No");
 	else
-		$drives = _("Yes");
+		$drives = i("Yes");
 	if($data["mapprinters"] == 0)
-		$printers = _("No");
+		$printers = i("No");
 	else
-		$printers = _("Yes");
+		$printers = i("Yes");
 	if($data["mapserial"] == 0)
-		$serial = _("No");
+		$serial = i("No");
 	else
-		$serial = _("Yes");
+		$serial = i("Yes");
 
 	print "<div align=center>\n";
 	if($type == 0) {
-		print "<H2>" . _("Personal Information") . "</H2>\n";
-		print "<H3>" . _("Submit the following changes?") . "</H3>\n";
+		print "<H2>" . i("Personal Information") . "</H2>\n";
+		print "<H3>" . i("Submit the following changes?") . "</H3>\n";
 		print "<table>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("Preferred Name:") . "</TH>\n";
+		print "    <TH align=right>" . i("Preferred Name:") . "</TH>\n";
 		print "    <TD>" . $data["preferredname"] . "</TD>\n";
 		print "  </TR>\n";
 		print "</table>\n";
 		if($user['affiliation'] == 'Local' &&
 		   ! empty($data['newpassword'])) {
-			print _("New password will be submitted") . "<br>\n";
+			print i("New password will be submitted") . "<br>\n";
 		}
 	}
 	elseif($type == 1) {
-		print "<H2>" . _("RDP Preferences") . "</H2>\n";
-		print "<H3>" . _("Submit the following changes?") . "</H3>\n";
+		print "<H2>" . i("RDP Preferences") . "</H2>\n";
+		print "<H3>" . i("Submit the following changes?") . "</H3>\n";
 		print "<table>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("Resolution:") . "</TH>\n";
+		print "    <TH align=right>" . i("Resolution:") . "</TH>\n";
 		print "    <TD>" . $data["resolution"] . "</TD>\n";
 		print "  </TR>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("Color Depth:") . "</TH>\n";
+		print "    <TH align=right>" . i("Color Depth:") . "</TH>\n";
 		$colordepth = array("8" => "8", "16" => "16", "24" => "24", "32" => "32");
 		print "    <TD>" . $colordepth[$data["bpp"]] . "</TD>\n";
 		print "  </TR>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("Audio:") . "</TH>\n";
+		print "    <TH align=right>" . i("Audio:") . "</TH>\n";
 		print "    <TD>$audio</TD>\n";
 		print "  </TR>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("Map Local Drives:") . "</TH>\n";
+		print "    <TH align=right>" . i("Map Local Drives:") . "</TH>\n";
 		print "    <TD>$drives</TD>\n";
 		print "  </TR>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("Map Local Printers:") . "</TH>\n";
+		print "    <TH align=right>" . i("Map Local Printers:") . "</TH>\n";
 		print "    <TD>$printers</TD>\n";
 		print "  </TR>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("Map Local Serial Ports:") . "</TH>\n";
+		print "    <TH align=right>" . i("Map Local Serial Ports:") . "</TH>\n";
 		print "    <TD>$serial</TD>\n";
 		print "  </TR>\n";
 		print "  <TR>\n";
-		print "    <TH align=right>" . _("RDP Port") . ":</TH>\n";
+		print "    <TH align=right>" . i("RDP Port") . ":</TH>\n";
 		print "    <TD>{$data['rdpport']}</TD>\n";
 		print "  </TR>\n";
 		print "</table>\n";
@@ -443,14 +443,14 @@ function confirmUserPrefs($type) {
 	print "      <FORM action=\"" . BASEURL . SCRIPT . "\" method=post>\n";
 	$cont = addContinuationsEntry('submituserprefs', $data, SECINWEEK, 0, 0);
 	print "      <INPUT type=hidden name=continuation value=\"$cont\">\n";
-	print "      <INPUT type=submit value=" . _("Submit") . ">\n";
+	print "      <INPUT type=submit value=" . i("Submit") . ">\n";
 	print "      </FORM>\n";
 	print "    </TD>\n";
 	print "    <TD>\n";
 	print "      <FORM action=\"" . BASEURL . SCRIPT . "\" method=post>\n";
 	$cont = addContinuationsEntry('userpreferences');
 	print "      <INPUT type=hidden name=continuation value=\"$cont\">\n";
-	print "      <INPUT type=submit value=" . _("Cancel") . ">\n";
+	print "      <INPUT type=submit value=" . i("Cancel") . ">\n";
 	print "      </FORM>\n";
 	print "    </TD>\n";
 	print "  </TR>\n";
@@ -561,7 +561,7 @@ function submitGeneralPreferences() {
 		$_SESSION['user']['usepublickeys'] = $newval;
 		$user['usepublickeys'] = $newval;
 	}
-	if($pubkeyauth == 2 && preg_match('|^[-a-zA-Z0-9\+/ @=\.]*$|', $pubkeys)) {
+	if($pubkeyauth == 2 && preg_match('|^[-a-zA-Z0-9\+/ @=\.\n\r]*$|', $pubkeys)) {
 		if(get_magic_quotes_gpc())
 			$pubkeys = stripslashes($pubkeys);
 		$_pubkeys = mysql_real_escape_string($pubkeys);
@@ -611,11 +611,11 @@ function processUserPrefsInput($checks=1) {
 
 	if(strlen($return["preferredname"]) > 25) {
 	   $submitErr |= PREFNAMEERR;
-	   $submitErrMsg[PREFNAMEERR] = _("Preferred name can only be up to 25 characters");
+	   $submitErrMsg[PREFNAMEERR] = i("Preferred name can only be up to 25 characters");
 	}
 	if(! preg_match('/^[a-zA-Z ]*$/', $return["preferredname"])) {
 	   $submitErr |= PREFNAMEERR;
-	   $submitErrMsg[PREFNAMEERR] = _("Preferred name can only contain letters and spaces");
+	   $submitErrMsg[PREFNAMEERR] = i("Preferred name can only contain letters and spaces");
 	}
 	if($user['affiliation'] == 'Local' && array_key_exists('newpassword', $_POST)) {
 		$return['newpassword'] = $_POST['newpassword'];
@@ -629,35 +629,39 @@ function processUserPrefsInput($checks=1) {
 		if(! empty($return['newpassword']) && ! empty($confirmpwd) &&
 		   ! validateLocalAccount($user['unityid'], $curr)) {
 			$submitErr |= LOCALPASSWORDERR;
-			$submitErrMsg[LOCALPASSWORDERR] = _("Password incorrect");
+			$submitErrMsg[LOCALPASSWORDERR] = i("Password incorrect");
 		}
 		elseif((empty($return['newpassword']) && ! empty($confirmpwd)) ||
 		   (! empty($return['newpassword']) && empty($confirmpwd)) ||
 		   ($return['newpassword'] != $confirmpwd)) {
 			$submitErr |= LOCALPASSWORDERR;
-			$submitErrMsg[LOCALPASSWORDERR] = _("Passwords do not match");
+			$submitErrMsg[LOCALPASSWORDERR] = i("Passwords do not match");
 		}
 	}
+	if(array_key_exists('preferredname', $_POST) ||
+		array_key_exists('newpassword', $_POST))
+		$return['rdpport'] = $user['rdpport'];
+
 	if($return['rdpport'] != $user['rdpport']) {
 		$requests = getUserRequests('all');
 		$nochange = 0;
 		foreach($requests as $req) {
-			if(preg_match('/^(3|8|24|25|26|27|28|29)$/', $req['currstateid']) ||
+			if(preg_match('/^(3|8|10|24|25|26|27|28|29)$/', $req['currstateid']) ||
 			   ($req['currstateid'] == 14 &&
-				preg_match('/^(3|8|24|25|26|27|28|29)$/', $req['laststateid']))) {
+				preg_match('/^(3|8|10|24|25|26|27|28|29)$/', $req['laststateid']))) {
 				$nochange = 1;
 				break;
 			}
 		}
 		if($nochange) {
 			$submitErr |= RDPPORTERR;
-			$submitErrMsg[RDPPORTERR] = _("RDP Port cannot be changed while you have active reservations");
+			$submitErrMsg[RDPPORTERR] = i("RDP Port cannot be changed while you have active reservations");
 		}
 	}
 	if(! ($submitErr & RDPPORTERR) &&
 	   ($return['rdpport'] < 1024 || $return['rdpport'] > 65535)) {
 		$submitErr |= RDPPORTERR;
-		$submitErrMsg[RDPPORTERR] = _("RDP Port must be between 1024 and 65535");
+		$submitErrMsg[RDPPORTERR] = i("RDP Port must be between 1024 and 65535");
 	}
 	return $return;
 }
