@@ -72,22 +72,8 @@ function editVMInfo() {
 		print "<div id=vmhostdata class=hidden>\n";
 		print "<table summary=\"\">\n";
 		print "  <tr>\n";
-		print "    <th align=right>VM limit:</th>\n";
-		print "    <td>\n";
-		$cont = addContinuationsEntry('updateVMlimit');
-		print "      <input dojoType=\"dijit.form.NumberSpinner\"\n";
-		print "             constraints=\"{min:1,max:" . MAXVMLIMIT . "}\"\n";
-		print "             maxlength=\"3\"\n";
-		print "             id=\"vmlimit\"\n";
-		print "             intermediateChanges=\"true\"\n";
-		print "             onChange=\"updateVMlimit('$cont')\">\n";
-		print "    </td>\n";
-		print "  </tr>\n";
-		#$cont = addContinuationsEntry('changeVMprofile');
-		print "  <tr>\n";
 		print "    <th align=right>VM Profile:</th>\n";
 		print "    <td>\n";
-		#printSelectInput("vmprofileid", $profiles, -1, 0, 0, 'vmprofileid', "onchange=changeVMprofile('$cont')");
 		print "      <div dojoType=\"dijit.TitlePane\" id=vmprofile></div>\n";
 		print "    </td>\n";
 		print "  </tr>\n";
@@ -114,6 +100,7 @@ function editVMInfo() {
 		print "VMs assigned to host:<br>\n";
 		print "<select name=currvms multiple id=currvms size=15 onChange=showVMstate()>\n";
 		print "</select><br>\n";
+		print "Assigned VMs: <span id=\"assignedcnt\">0</span><br>\n";
 		print "State of selected vm:<br>\n";
 		print "<span id=vmstate></span>\n";
 		print "<div id=\"noaccessdiv\" class=\"hidden\"><hr>VMs assigned to ";
@@ -149,19 +136,6 @@ function editVMInfo() {
 		print "</td>\n";
 		print "</tr><tbody/></table>\n";
 		print "</div><br><br>\n";
-
-		/*print "<div dojoType=\"dijit.Dialog\"\n";
-		print "     id=\"profileDlg\"\n";
-		print "     title=\"Change Profile\">\n";
-		print "You have selected to change the VM Profile for this host.<br>\n";
-		print "Doing this will attempt to move any future reservations on the<br>\n";
-		print "host's VMs to other VMs and will submit a reload reservation for this<br>\n";
-		print "host after any active reservations on its VMs.<br><br>\n";
-		print "Are you sure you want to do this?<br><br>\n";
-		print "<button onclick=\"submitChangeProfile()\">Update VM Profile</button>\n";
-		print "<button onclick=\"dijit.byId('profileDlg').hide()\">Cancel</button>\n";
-		print "<input type=hidden id=changevmcont>\n";
-		print "</div>\n";*/
 	}
 	print "</div>\n";
 
@@ -285,20 +259,6 @@ function editVMInfo() {
 	print "    </select><img tabindex=0 src=\"images/helpicon.png\" id=\"genmac1help\" /></td>\n";
 	print "  </tr>\n";
 	print "  <tr>\n";
-	print "    <th align=right>RSA Public Key:</th>\n";
-	print "    <td>\n";
-	print "      <span id=prsapub dojoType=\"dijit.InlineEditBox\" editor=\"dijit.form.Textarea\" onChange=\"updateProfile('prsapub','rsapub')\"></span>\n";
-	print "      <img tabindex=0 src=\"images/helpicon.png\" id=\"rsapubhelp\" />\n";
-	print "    </td>\n";
-	print "  </tr>\n";
-	print "  <tr>\n";
-	print "    <th align=right>RSA Private Key File:</th>\n";
-	print "    <td>\n";
-	print "      <span id=prsakey dojoType=\"dijit.InlineEditBox\" onChange=\"updateProfile('prsakey','rsakey');\"></span>\n";
-	print "      <img tabindex=0 src=\"images/helpicon.png\" id=\"rsakeyhelp\" />\n";
-	print "    </td>\n";
-	print "  </tr>\n";
-	print "  <tr>\n";
 	print "    <th align=right>Username:</th>\n";
 	print "    <td><span id=pusername dojoType=\"dijit.InlineEditBox\" onChange=\"updateProfile('pusername', 'username');\"></span><img tabindex=0 src=\"images/helpicon.png\" id=\"usernamehelp\" /></td>\n";
 	print "  </tr>\n";
@@ -332,57 +292,51 @@ function editVMInfo() {
 	print "</div>\n";
 
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"resourcepathhelp\">\n";
-	print _("Resource Path only needs to be configured if VMware vCenter is used. It defines the location where VMs will be created in the vCenter inventory tree. The inventory tree contains at least one Datacenter, and may also contain Folders, Clusters, and Resource Pools.<br>Example: /DatacenterA/Folder1/Cluster2/ResourcePool3");
+	print i("Resource Path only needs to be configured if VMware vCenter is used. It defines the location where VMs will be created in the vCenter inventory tree. The inventory tree contains at least one Datacenter, and may also contain Folders, Clusters, and Resource Pools.<br>Example: /DatacenterA/Folder1/Cluster2/ResourcePool3");
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"folderpathhelp\">\n";
-	print _("Folder Path only needs to be configured if VMware vCenter is used. It defines the location where VMs will reside according to the vSphere Client's 'VMs and Templates' inventory view. This view will contain at least 1 Datacenter at the root level of the tree. Underneath each Datacenter, VMs may optionally be organized into VM Folders. Example: /DatacenterA/VCL_VMs");
+	print i("Folder Path only needs to be configured if VMware vCenter is used. It defines the location where VMs will reside according to the vSphere Client's 'VMs and Templates' inventory view. This view will contain at least 1 Datacenter at the root level of the tree. Underneath each Datacenter, VMs may optionally be organized into VM Folders. Example: /DatacenterA/VCL_VMs");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"repositorypathhelp\">\n";
-	print _("(Optional) The path where master copies of images are stored which are used to transfer images to VM host datastores or to other repositories. This is required if multiple management nodes need to share images. VMs do not run directly off of the images stored in the repository. It can refer to and be mounted on either the management node or VM host.");
+	print i("(Optional) The path where master copies of images are stored which are used to transfer images to VM host datastores or to other repositories. This is required if multiple management nodes need to share images. VMs do not run directly off of the images stored in the repository. It can refer to and be mounted on either the management node or VM host.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"repositoryimgtypehelp\">\n";
-	print _("Virtual disk type of the images stored here.");
+	print i("Virtual disk type of the images stored here.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"dspathhelp\">\n";
-	print _("The location where master copies of images are stored which are used by running VMs. It can be either on local or network storge. If on network storage, it can be shared among multiple hosts.");
+	print i("The location where master copies of images are stored which are used by running VMs. It can be either on local or network storge. If on network storage, it can be shared among multiple hosts.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"datastoreimgtypehelp\">\n";
-	print _("Virtual disk type of the images stored here.");
+	print i("Virtual disk type of the images stored here.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"vmdiskhelp\">\n";
-	print _("Defines whether the Virtual Disk Path storage is dedicated to a single host or shared among multiple hosts. If set to dedicated, Repository Path must be definied and VCL will remove copies of images in the Virtual Disk Path to free up space if they are not being used.");
+	print i("Defines whether the Virtual Disk Path storage is dedicated to a single host or shared among multiple hosts. If set to dedicated, Repository Path must be definied and VCL will remove copies of images in the Virtual Disk Path to free up space if they are not being used.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"vmpathhelp\">\n";
-	print _("(Optional) This is the path on VM host where VM working directories will reside. If not configured, the Datastore Path location will be used. It can be either on local or network storge. It should be dedicated for each VM host and should be optimized for read-write performance.");
+	print i("(Optional) This is the path on VM host where VM working directories will reside. If not configured, the Datastore Path location will be used. It can be either on local or network storge. It should be dedicated for each VM host and should be optimized for read-write performance.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"vs0help\">\n";
-	print _("The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 0 should be your public or private network.");
+	print i("The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 0 should be your public or private network.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"vs1help\">\n";
-	print _("The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 1 should be your public or private network.");
+	print i("The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 1 should be your public or private network.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"vs2help\">\n";
-	print _("(Optional) The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 2 is optional for connecting the VM to additional networks.");
+	print i("(Optional) The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 2 is optional for connecting the VM to additional networks.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"vs3help\">\n";
-	print _("(Optional) The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 3 is optional for connecting the VM to additional networks.");
+	print i("(Optional) The VM Network parameters should match the network names configured on the VM host. For ESXi, the Virtual Switch parameters must match the Virtual Machine Port Group Network Labels configured in the vSphere Client. VM Network 3 is optional for connecting the VM to additional networks.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"genmac0help\">\n";
-	print _("Specifies whether VMs are assigned MAC addresses defined in the VCL database or if random MAC addresses should be assigned.");
+	print i("Specifies whether VMs are assigned MAC addresses defined in the VCL database or if random MAC addresses should be assigned.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"genmac1help\">\n";
-	print _("Specifies whether VMs are assigned MAC addresses defined in the VCL database or if random MAC addresses should be assigned.");
-	print "</div>\n";
-	print "<div dojoType=\"dijit.Tooltip\" connectId=\"rsapubhelp\">\n";
-	print _("(Optional) In order to encrypt the VM Host password in the database, create an RSA public/private key pair on the relevant management node. Enter the public key here. Note that while this value will be available to every management node in your system, only those management nodes with the designated private key will be able to decrypt the password.");
-	print "</div>\n";
-	print "<div dojoType=\"dijit.Tooltip\" connectId=\"rsakeyhelp\">\n";
-	print _("(Optional) In order to decrypt an encrypted VM Host password, enter the path to a private key on the management node. Any management node without this private key will not be able to decrypt the password.");
+	print i("Specifies whether VMs are assigned MAC addresses defined in the VCL database or if random MAC addresses should be assigned.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"usernamehelp\">\n";
-	print _("Name of the administrative or root user residing on the VM host.");
+	print i("Name of the administrative or root user residing on the VM host.");
 	print "</div>\n";
 	print "<div dojoType=\"dijit.Tooltip\" connectId=\"passwordhelp\">\n";
-	print _("Password of the administrative or root user residing on the VM host.");
+	print i("Password of the administrative or root user residing on the VM host.");
 	print "</div>\n";
 }
 
@@ -471,7 +425,7 @@ function vmhostdata() {
 		$qh = doQuery($query, 101);
 		while($row = mysql_fetch_assoc($qh)) {
 			$movevms[] = array('id' => $row['id'],
-			                 'time' => strtolower($row['start']),
+			                 'time' => strtolower($row['start']) . ' ' . date('T'),
 			                 'hostname' => $currvms[$row['computerid']]['name']);
 			unset($currvms[$row['computerid']]);
 		}
@@ -484,8 +438,7 @@ function vmhostdata() {
 	$noaccess = array_merge($noaccess);
 	$freevms = array_merge($freevms);
 	$cont = addContinuationsEntry('AJchangeVMprofile', array(), 3600, 1, 0);
-	$arr = array('vmlimit' => $data[$vmhostid]['vmlimit'],
-	             'profile' => $data[$vmhostid]['vmprofiledata'],
+	$arr = array('profile' => $data[$vmhostid]['vmprofiledata'],
 	             'continuation' => $cont,
 	             'allvms' => $allvms,
 	             'currvms' => $currvms,
@@ -506,7 +459,6 @@ function vmhostdata() {
 /// \b computerid - id of computer\n
 /// \b name - hostname of computer\n
 /// \b hostname - hostname of computer\n
-/// \b vmlimit - maximum number of vm's host can handle\n
 /// \b vmprofileid - id of vm profile\n
 /// \b vmprofiledata - array of data about the vm's profile as returned from
 /// getVMProfiles
@@ -520,7 +472,6 @@ function getVMHostData($id='') {
 	       .        "vh.computerid, " 
 	       .        "c.hostname AS name, "
 	       .        "c.hostname, "
-	       .        "vh.vmlimit, "
 	       .        "vh.vmprofileid "
 	       . "FROM vmhost vh, " 
 	       .      "computer c "
@@ -541,67 +492,6 @@ function getVMHostData($id='') {
 	return $ret;
 }
 
-////////////////////////////////////////////////////////////////////////////////
-///
-/// \fn updateVMlimit()
-///
-/// \brief updates the vmlimit for the submitted vmhostid
-///
-////////////////////////////////////////////////////////////////////////////////
-function updateVMlimit() {
-	global $mysql_link_vcl;
-	$vmhostid = processInputVar('vmhostid', ARG_NUMERIC);
-	$newlimit = processInputVar('newlimit', ARG_NUMERIC);
-
-	$data = getVMHostData($vmhostid);
-
-	if($data[$vmhostid]['vmlimit'] == $newlimit) {
-		sendJSON(array('status' => 'SUCCESS'));
-		return;
-	}
-	$resources = getUserResources(array("computerAdmin"), array("administer"));
-	if(! array_key_exists($data[$vmhostid]['computerid'], $resources['computer'])) {
-		$rc = array('status' => 'ERROR',
-		            'msg' => "You do not have access to manage this host.");
-		sendJSON($rc);
-		return;
-	}
-
-	if($newlimit < 0 || $newlimit > MAXVMLIMIT) {
-		$rc = array('status' => 'ERROR',
-		            'msg' => "ERROR: newlimit out of range");
-		sendJSON($rc);
-		return;
-	}
-
-	# get number of vms assigned to vmhost
-	$query = "SELECT COUNT(id) as assigned "
-	       . "FROM computer "
-	       . "WHERE type = 'virtualmachine' AND "
-	       .       "vmhostid = $vmhostid AND "
-	       .       "deleted = 0";
-	$qh = doQuery($query, 101);
-	$row = mysql_fetch_assoc($qh);
-	if($row['assigned'] > $newlimit) {
-		$rc = array('status' => 'LIMIT',
-		            'msg' => "Cannot reduce VM limit below the current number of assigned VMs",
-		            'limit' => $row['assigned']);
-		sendJSON($rc);
-		return;
-	}
-
-	$query = "UPDATE vmhost SET vmlimit = $newlimit WHERE id = $vmhostid";
-	$qh = doQuery($query, 101);
-	if(mysql_affected_rows($mysql_link_vcl) == 0) {
-		$rc = array('status' => 'ERROR',
-		            'msg' => "ERROR: failed to update vmlimit",
-		            'data' => $data);
-		sendJSON($rc);
-		return;
-	}
-	sendJSON(array('status' => 'SUCCESS'));
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 ///
 /// \fn AJvmToHost()
@@ -622,17 +512,6 @@ function AJvmToHost() {
 		return;
 	}
 
-	# find out how many vms are currently on the host
-	$query = "SELECT COUNT(id) "
-	       . "FROM computer "
-	       . "WHERE vmhostid = $hostid";
-	$qh = doQuery($query, 101);
-	$row = mysql_fetch_row($qh);
-	if($row[0] >= $hostdata[$hostid]['vmlimit']) {
-		sendJSON(array('failed' => 'vmlimit'));
-		return;
-	}
-
 	$adds = array();
 	$fails = array();
 
@@ -740,7 +619,7 @@ function AJvmFromHost() {
 		if($row = mysql_fetch_assoc($qh)) {
 			$checks[] = array('id' => $compid,
 			                  'hostname' => $compdata[$compid]['hostname'],
-			                  'end' => strtolower($row['end']),
+			                  'end' => strtolower($row['end']) . ' ' . date('T'),
 			                  'end2' => $row['end2']);
 		}
 		else {
@@ -931,7 +810,7 @@ function AJupdateVMprofileItem() {
 	}
 	$profileid = processInputVar('profileid', ARG_NUMERIC);
 	$item = processInputVar('item', ARG_STRING);
-	if(! preg_match('/^(profilename|imageid|resourcepath|folderpath|repositorypath|repositoryimagetypeid|datastorepath|datastoreimagetypeid|vmdisk|vmpath|virtualswitch[0-3]|username|password|eth0generated|eth1generated|rsakey|rsapub)$/', $item)) {
+	if(! preg_match('/^(profilename|imageid|resourcepath|folderpath|repositorypath|repositoryimagetypeid|datastorepath|datastoreimagetypeid|vmdisk|vmpath|virtualswitch[0-3]|username|password|eth0generated|eth1generated)$/', $item)) {
 		print "alert('Invalid data submitted.');";
 		return;
 	}
@@ -967,27 +846,90 @@ function AJupdateVMprofileItem() {
 
 	$item = mysql_real_escape_string($item);
 	$profile = getVMProfiles($profileid);
-	if($item == 'password' && $profile[$profileid]['rsapub']) {
-		$encrypted = encryptDataAsymmetric($newvalue, $profile[$profileid]['rsapub']);
-		$escaped = mysql_real_escape_string($encrypted);
-		$query = "UPDATE vmprofile "
-		       . "SET `encryptedpasswd` = '$escaped' "
-		       . "WHERE id = $profileid";
-		doQuery($query, 101);
-		# don't store the unencrypted password
-		$newvalue2 = 'NULL';
-		$newvalue = '';
+	if($item == 'password') {
+		$pwdlen = strlen($newvalue);
+		if($pwdlen == 0) {
+			if($profile[$profileid]['pwdlength'] != 0) {
+				$secretid = getSecretKeyID('vmprofile', 'secretid', $profileid);
+				if($secretid === NULL) {
+					print "dojo.byId('savestatus').innerHTML = '';";
+					print "alert('Error saving password');";
+					return;
+				}
+				deleteSecretKeys($secretid);
+				$query = "UPDATE vmprofile "
+				       . "SET password = NULL, "
+				       .     "secretid = NULL "
+				       . "WHERE id = $profileid";
+				doQuery($query);
+			}
+		}
+		else {
+			$secretid = getSecretKeyID('vmprofile', 'secretid', $profileid);
+			# check that we have a cryptsecret entry for this secret
+			$cryptkeyid = getCryptKeyID();
+			if($cryptkeyid === NULL) {
+				print "dojo.byId('savestatus').innerHTML = '';";
+				print "alert('Error saving password');";
+				return;
+			}
+			$query = "SELECT cryptsecret "
+			       . "FROM cryptsecret "
+			       . "WHERE cryptkeyid = $cryptkeyid AND "
+			       .       "secretid = $secretid";
+			$qh = doQuery($query);
+			if(! ($row = mysql_fetch_assoc($qh))) {
+				# generate a new secret
+				$newsecretid = getSecretKeyID('vmprofile', 'secretid', 0);
+				$delids = array($secretid);
+				if($newsecretid == $secretid) {
+					$delids[] = $secretid;
+					$newsecretid = getSecretKeyID('addomain', 'secretid', 0);
+				}
+				$delids = implode(',', $delids);
+				# encrypt new secret with any management node keys
+				$secretidset = array();
+				$query = "SELECT ck.hostid AS mnid "
+				       . "FROM cryptkey ck "
+				       . "JOIN cryptsecret cs ON (ck.id = cs.cryptkeyid) "
+				       . "WHERE cs.secretid = $secretid AND "
+				       .       "ck.hosttype = 'managementnode'";
+				$qh = doQuery($query);
+				while($row = mysql_fetch_assoc($qh))
+					$secretidset[$row['mnid']][$newsecretid] = 1;
+				$values = getMNcryptkeyUpdates($secretidset, $cryptkeyid);
+				addCryptSecretKeyUpdates($values);
+				$secretid = $newsecretid;
+				# clean up old cryptsecret entries for management nodes
+				$query = "DELETE FROM cryptsecret WHERE secretid IN ($delids)";
+				doQuery($query);
+			}
+			if($secretid === NULL) {
+				print "dojo.byId('savestatus').innerHTML = '';";
+				print "alert('Error saving password');";
+				return;
+			}
+			$encpass = encryptDBdata($newvalue, $secretid);
+			$query = "UPDATE vmprofile "
+			       . "SET password = '$encpass', "
+			       .     "secretid = '$secretid', "
+			       .     "rsapub = NULL, "
+			       .     "rsakey = NULL, "
+			       .     "encryptedpasswd = NULL "
+			       . "WHERE id = $profileid";
+			doQuery($query);
+		}
+		print "dojo.byId('savestatus').innerHTML = 'Saved'; ";
+		print "setTimeout(function() {dojo.byId('savestatus').innerHTML = '';}, 3000); ";
+		print "curprofile.pwdlength = $pwdlen;";
+		return;
 	}
-	else if($profile[$profileid][$item] == $newvalue)
+	elseif($profile[$profileid][$item] == $newvalue)
 		return;
 	$query = "UPDATE vmprofile "
 	       . "SET `$item` = $newvalue2 "
 	       . "WHERE id = $profileid";
 	doQuery($query, 101);
-	if($item == 'password') {
-		print "document.getElementById('savestatus').innerHTML = 'Saved'; ";
-		print "setTimeout(function() {document.getElementById('savestatus').innerHTML = '';}, 3000); ";
-	}
 	$newvalue = preg_replace("/'/", "\\'", $newvalue);
 	print "curprofile.$item = '$newvalue';";
 }
@@ -1013,11 +955,18 @@ function AJnewProfile() {
 		return;
 	}
 	$imageid = getImageId('noimage');
-	$query = "INSERT INTO vmprofile (profilename, imageid) VALUES ('$newprofile', $imageid)";
+	$query = "INSERT INTO vmprofile "
+	       .        "(profilename, "
+	       .        "imageid, "
+	       .        "repositoryimagetypeid, "
+	       .        "datastoreimagetypeid) "
+	       . "VALUES "
+	       .       "('$newprofile', "
+	       .       "$imageid, "
+	       .       "(SELECT id FROM imagetype WHERE name = 'vmdk'), "
+	       .       "(SELECT id FROM imagetype WHERE name = 'vmdk'))";
 	doQuery($query, 101);
-	$qh = doQuery("SELECT LAST_INSERT_ID() FROM vmprofile", 101);
-	$row = mysql_fetch_row($qh);
-	$newid = $row[0];
+	$newid = dbLastInsertID();
 	AJprofileData($newid);
 }
 
