@@ -14,6 +14,9 @@
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
+if("Notification" in window)
+	window.Notification.requestPermission();
+
 var resSubmitted = 0;
 var suggestTimeData = {}
 var resbtntxt = '';
@@ -25,11 +28,11 @@ var revisiongrids;
 var waittimeobj;
 var waittimeh;
 
-var profilesstoredata = {
+/*var profilesstoredata = {
 	identifier: 'id',
 	label: 'name',
 	items: []
-}
+}*/
 
 function generalReqCB(data, ioArgs) {
 	eval(data);
@@ -40,7 +43,8 @@ function initViewRequests(imaging) {
 	if(typeof(dijit) == "undefined" ||
 	   typeof(dijit.byId) == "undefined" ||
 	   typeof(images) == "undefined" ||
-	   dojo.byId('limitstart') == null) {
+	   dojo.byId('limitstart') == null ||
+	   (imaging && typeof(dijit.byId('deployimage')) == 'undefined')) {
 		setTimeout(function() {initViewRequests(imaging);}, 100);
 		return;
 	}
@@ -89,7 +93,7 @@ function resetNewResDlg() {
 	setLastImage();
 	dojo.byId('basicrdo').checked = true;
 	selectResType();
-	dijit.byId('deployprofileid').reset();
+	//dijit.byId('deployprofileid').reset();
 	if(dijit.byId('nousercheck'))
 		dijit.byId('nousercheck').reset();
 	dijit.byId('deployname').reset();
@@ -144,7 +148,7 @@ function selectResType() {
 		dojo.removeClass('limitstart', 'hidden');
 		dojo.removeClass('durationend', 'hidden');
 		dojo.addClass('whentitleserver', 'hidden');
-		dojo.addClass('deployprofileslist', 'hidden');
+		//dojo.addClass('deployprofileslist', 'hidden');
 		dojo.addClass('nrnamespan', 'hidden');
 		dojo.addClass('nrservergroupspan', 'hidden');
 		//dojo.addClass('nrmacaddrspan', 'hidden');
@@ -214,10 +218,10 @@ function selectResType() {
 		dojo.addClass('limitstart', 'hidden');
 		dojo.addClass('durationend', 'hidden');
 		dojo.removeClass('whentitleserver', 'hidden');
-		if(profilesstore._arrayOfAllItems.length != 0 &&
+		/*if(profilesstore._arrayOfAllItems.length != 0 &&
 		   (profilesstore._arrayOfAllItems.length != 1 ||
 		   profilesstore._arrayOfAllItems[0].name != _('(New Profile)')))
-			dojo.removeClass('deployprofileslist', 'hidden');
+			dojo.removeClass('deployprofileslist', 'hidden');*/
 		dojo.removeClass('nrnamespan', 'hidden');
 		dojo.removeClass('nrservergroupspan', 'hidden');
 		//dojo.removeClass('nrmacaddrspan', 'hidden');
@@ -430,7 +434,9 @@ function getDeployData(waitonly) {
 		}
 		else {
 			var tmp = dojo.byId('deploystartday').value;
-			var date = new Date(tmp * 1000);
+			tmp = new Date(tmp * 1000);
+			var offset = tmp.getTimezoneOffset() * 60000;
+			var date = new Date(tmp.getTime() + offset);
 			var hour = parseInt(dojo.byId('deployhour').value);
 			var m = dojo.byId('deploymeridian').value;
 			if(m == 'pm' && hour < 12)
@@ -482,7 +488,7 @@ function getDeployData(waitonly) {
 		data.nousercheck = 1;
 	else
 		data.nousercheck = 0;
-	data.profileid = dojo.byId('appliedprofileid').value;
+	//data.profileid = dojo.byId('appliedprofileid').value;
 	data.name = dijit.byId('deployname').get('value');
 	data.admingroupid = getSelectValue('deployadmingroup');
 	data.logingroupid = getSelectValue('deploylogingroup');
@@ -586,6 +592,7 @@ function showSuggestedTimesCB(data, ioArgs) {
 	else if(data.items.status == 'noextend') {
 		dijit.byId('suggestedTimes').hide();
 		dojo.byId('editResDlgContent').innerHTML = data.items.html;
+		dojo.byId('editResDlgPartialMsg').innerHTML = '';
 		dojo.byId('editResDlgErrMsg').innerHTML = '';
 		dijit.byId('editResDlgBtn').set('style', 'display: none');
 		dijit.byId('editResCancelBtn').set('label', _('Okay'));
@@ -613,8 +620,7 @@ function useSuggestedEditSlot() {
 	if(dojo.byId('deploystartday')) {
 		var sel = dojo.byId('deploystartday');
 		for(var i = 0; i < sel.options.length; i++) {
-			var testdate = new Date(parseInt(sel.options[i].value + '000'));
-			if(s.getDay() == testdate.getDay()) {
+			if(s.getDayName() == sel.options[i].innerHTML) {
 				sel.value = sel.options[i].value;
 				break;
 			}
@@ -799,6 +805,18 @@ function setMaxRequestLength(minutes) {
 			text = '1 ' + _('hour');
 			newminutes = 60;
 		}
+		// if option > 45 days, add as weeks
+		else if(parseInt(obj.options[i].value) > 64700) {
+			var len = parseInt(obj.options[i].value);
+			if(len == 64800)
+				len = 60480;
+			if(len % 10080)
+				len = len - (len % 10080);
+			else
+				len = len + 10080;
+			text = len / 10080 + ' ' + _('weeks');
+			newminutes = len;
+		}
 		// if option > 46 hours, add as days
 		else if(parseInt(obj.options[i].value) > 2640) {
 			var len = parseInt(obj.options[i].value);
@@ -1323,6 +1341,14 @@ function showWindow(name) {
 	obj.show();
 }
 
+function notifyResReady(names) {
+	if(! ("Notification" in window) || ! Notification.permission) {
+		//console.log('notifications not supported');
+		return;
+	}
+	var note = new Notification("VCL Reservations ready", { tag: 'reqready', body: names });
+}
+
 function connectRequest(cont) {
 	RPCwrapper({continuation: cont}, connectRequestCB, 1);
 }
@@ -1339,7 +1365,8 @@ function connectRequestCB(data, ioArgs) {
 }
 
 function endReservation(cont) {
-	dojo.byId('deletecontholder').value = cont;
+	if(dojo.byId('deletecontholder'))
+		dojo.byId('deletecontholder').value = cont;
 	RPCwrapper({continuation: cont}, endReservationCB, 1, 30000);
 }
 
@@ -1362,7 +1389,8 @@ function endReservationCB(data, ioArgs) {
 		dijit.byId('serverdeletedlg').show();
 		return;
 	}
-	if(dijit.byId('serverdeletedlg').open) {
+	if(dijit.byId('serverdeletedlg') && 
+	   dijit.byId('serverdeletedlg').open) {
 		dijit.byId('serverdeletedlg').hide();
 		dijit.byId('serverDeleteDlgBtn').set('disabled', false);
 	}
@@ -1432,6 +1460,7 @@ function editReservationCB(data, ioArgs) {
 		return;
 	}
 	dojo.byId('editResDlgContent').innerHTML = data.items.html;
+	dojo.byId('editResDlgPartialMsg').innerHTML = '';
 	dojo.byId('editResDlgErrMsg').innerHTML = '';
 	AJdojoCreate('editResDlgContent');
 	if(data.items.status == 'nomodify') {
@@ -1477,6 +1506,7 @@ function hideEditResDlg() {
 		dijit.byId('logingrpsel').destroy();
 	if(dijit.byId('newnousercheck'))
 		dijit.byId('newnousercheck').destroy();
+	dojo.byId('editResDlgPartialMsg').innerHTML = '';
 	dojo.byId('editResDlgErrMsg').innerHTML = '';
 	dojo.byId('editrescont').value = '';
 	dojo.byId('editresid').value = '';
@@ -1484,6 +1514,7 @@ function hideEditResDlg() {
 }
 
 function resetEditResBtn() {
+	dojo.byId('editResDlgPartialMsg').innerHTML = '';
 	dojo.byId('editResDlgErrMsg').innerHTML = '';
 	dijit.byId('editResDlgBtn').set('label', _('Modify Reservation'));
 }
@@ -1527,6 +1558,11 @@ function submitEditReservation() {
 		                                      t.getMinutes());
 		var tmp = dijit.byId('day').value.match(/([0-9]{4})([0-9]{2})([0-9]{2})/);
 		var teststart = new Date(tmp[1], tmp[2] - 1, tmp[3], t.getHours(), t.getMinutes(), 0, 0);
+		var now = new Date();
+		if(teststart < now) {
+			dojo.byId('editResDlgErrMsg').innerHTML = _("The submitted start time is in the past.");
+			return;
+		}
 	}
 	if(dijit.byId('newnousercheck') && dijit.byId('newnousercheck').get('value') == 1)
 		data.newnousercheck = 1;
@@ -1574,6 +1610,10 @@ function submitEditReservation() {
 
 function submitEditReservationCB(data, ioArgs) {
    document.body.style.cursor = 'default';
+	if(data.items.status != 'success' && 'partialupdate' in data.items) {
+		dojo.byId('editResDlgPartialMsg').innerHTML = '<br>' + data.items.partialupdate + '<br><br>';
+		resRefresh();
+	}
 	if(data.items.status == 'error') {
 		dojo.byId('editResDlgErrMsg').innerHTML = data.items.errmsg;
 		dojo.byId('editrescont').value = data.items.cont;
@@ -1628,6 +1668,7 @@ function resGone(type) {
 		dojo.byId('editResDlgContent').innerHTML = _('The reservation you selected<br>to reinstall has expired.<br><br>');
 	}
 	dojo.byId('editresid').value = '';
+	dojo.byId('editResDlgPartialMsg').innerHTML = '';
 	dojo.byId('editResDlgErrMsg').innerHTML = '';
 	dijit.byId('editResDlgBtn').set('style', 'display: none');
 	dijit.byId('editResCancelBtn').set('label', _('Okay'));
@@ -1761,4 +1802,3 @@ function previewClickThroughCB(data, ioArgs) {
 	dojo.byId('clickthroughPreviewDlgContent').innerHTML = data.items.text;
 	dijit.byId('clickthroughpreviewdlg').show();
 }
-
