@@ -260,7 +260,7 @@ function initPage() {
 		buildExtraFilters();
 		
 		// set width of first column
-		resourcegrid.setCellWidth(0, '18px');
+		resourcegrid.setCellWidth(0, '21px');
 		resourcegrid.layout.cells[0].view.update();
 
 		// connect selection
@@ -291,6 +291,8 @@ function initPage() {
 		resourcestore.comparatorMap['procnumber'] = resource.nocasesort;
 		resourcestore.comparatorMap['procspeed'] = resource.nocasesort;
 		resourcestore.comparatorMap['network'] = resource.nocasesort;
+
+		dojo.connect(resourcegrid, '_onFetchComplete', function() {dojo.byId('computercount').innerHTML = 'Computers in table: ' + resourcegrid.rowCount;});
 	}
 }
 
@@ -363,7 +365,7 @@ function buildExtraFilters() {
 			litem['name'] = cells[i].name;
 		litem['hidden'] = cells[i].hidden;
 		if(i == 0)
-			litem['width'] = '18px';
+			litem['width'] = '21px';
 		else if(typeof cells[i].width != 'undefined')
 			litem['width'] = cells[i].width;
 		litem['editable'] = false;
@@ -406,7 +408,8 @@ function buildExtraFilters() {
 					autoComplete: false,
 					labelFunc: cbformatter,
 					labelType: 'html',
-					searchAttr: 'value'
+					searchAttr: 'value',
+					fetchProperties: {sort: [{attribute:"value"}]}
 				});
 				if(typeof item.width != 'undefined') {
 					if(item.width.match(/px/))
@@ -434,7 +437,8 @@ function buildExtraFilters() {
 		store: filterstore,
 		structure: layout,
 		canSort: function() {return false;},
-		onCellClick: combofocus
+		onCellClick: combofocus,
+		autoWidth: true
 	}, document.createElement('div'));
 	dojo.byId('extrafiltersdiv').appendChild(extrafiltergrid.domNode);
 	extrafiltergrid.startup();
@@ -496,6 +500,8 @@ function applyExtraFilters(value) {
 		resourcegrid.query[this.field] = new RegExp('.*' + value + '.*', 'i');
 	resourcegrid.setQuery(resourcegrid.query);
 
+	dojo.byId('computercount').innerHTML = 'Computers in table: ' + resourcegrid.rowCount;
+
 	var savelist = resource.selids;
 	resourcegrid.selection.clear();
 	var newselids = [];
@@ -918,6 +924,7 @@ function saveResourceCB(data, ioArgs) {
 					resourcegrid.store.setValue(item, 'platform', data.items.data.platform);
 					resourcegrid.store.setValue(item, 'schedule', data.items.data.schedule);
 					resourcegrid.store.setValue(item, 'currentimg', data.items.data.currentimg);
+					resourcegrid.store.setValue(item, 'imagerevision', data.items.data.imagerevision);
 					resourcegrid.store.setValue(item, 'nextimg', data.items.data.nextimg);
 					resourcegrid.store.setValue(item, 'ram', data.items.data.ram);
 					resourcegrid.store.setValue(item, 'procnumber', data.items.data.procnumber);
@@ -1085,6 +1092,24 @@ function hostsData() {
 	confirmAction(data);
 }
 
+function showReservations() {
+	var data = {continuation: dojo.byId('showreservationscont').value};
+	confirmAction(data);
+}
+
+function showReservationHistory() {
+	var compids = [];
+	dojo.forEach(resource.selids, function(id) {
+		compids.push(id.replace('chkb', ''));
+	});
+	if(compids.length > 3) {
+		alert('Due to the load this can introduce on the database server, only a maximum of 3 computers can be selected for viewing Reservation History.');
+		return;
+	}
+	var data = {continuation: dojo.byId('showreservationhistorycont').value};
+	confirmAction(data);
+}
+
 function confirmAction(data) {
 	dijit.popup.close(dijit.byId('actionmenu'));
 	var compids = [];
@@ -1236,4 +1261,6 @@ function compGroupFilterSelectionCB(data, ioArgs) {
 	query['id'] = new RegExp(data.items.regids);
 
 	resourcegrid.setQuery(query);
+
+	dojo.byId('computercount').innerHTML = 'Computers in table: ' + resourcegrid.rowCount;
 }
