@@ -29,14 +29,17 @@ Image.prototype.colformatter = function(value, rowIndex, obj) {
 	   obj.field == 'forcheckout' ||
 	   obj.field == 'checkuser' ||
 	   obj.field == 'rootaccess' ||
-	   obj.field == 'sethostname') {
+	   obj.field == 'sethostname' ||
+	   obj.field == 'adauthenabled') {
 		if(value == "0")
 			return '<span class="rederrormsg">' + _('false') + '</span>';
 		if(value == "1")
 			return '<span class="ready">' + _('true') + '</span>';
 	}
-	if(obj.field == 'maxinitialtime' && value == 0)
-		return '(unset)';
+	if((obj.field == 'maxinitialtime' && value == 0) ||
+	   (obj.field == 'addomain' && value == null) ||
+	   (obj.field == 'baseOU' && value == null))
+		return '(' + _('unset') + ')';
 	return value;
 }
 
@@ -70,6 +73,39 @@ function inlineEditResourceCB(data, ioArgs) {
 			dojo.addClass('sethostnamediv', 'hidden');
 		dojo.byId('connectmethodlist').innerHTML = data.items.data.connectmethods.join('<br>');
 		dijit.byId('connectmethodttd').set('href', data.items.data.connectmethodurl);
+		if(data.items.data.ostype == 'windows') {
+			dojo.removeClass('imageadauthbox', 'hidden');
+			if('addomainvals' in data.items.data)
+				var advalcnt = Object.keys(data.items.data.addomainvals).length;
+			else
+				var advalcnt = 0;
+			if(data.items.data.addomainid != null) {
+				dijit.byId('adauthenable').set('checked', true);
+				if('extraaddomainid' in data.items.data) {
+					var option = {value: data.items.data.extraaddomainid, label: data.items.data.addomain};
+					dijit.byId('addomainid').addOption([option]);
+					dijit.byId('addomainid').extraaddomainid = data.items.data.extraaddomainid;
+					dijit.byId('addomainid').extraaddomainou = data.items.data.extraaddomainou;
+				}
+				dijit.byId('addomainid').set('value', data.items.data.addomainid);
+				dijit.byId('baseou').set('value', data.items.data.baseOU);
+				if(advalcnt == 1 && ('extraaddomainid' in data.items.data))
+					dijit.byId('baseou').set('disabled', true);
+			}
+			else {
+				dijit.byId('adauthenable').set('checked', false);
+				dijit.byId('addomainid').reset();
+				dijit.byId('baseou').reset();
+				if(advalcnt == 0)
+					dijit.byId('adauthenable').set('disabled', true);
+			}
+		}
+		else {
+			dojo.addClass('imageadauthbox', 'hidden');
+			dijit.byId('adauthenable').set('checked', false);
+			dijit.byId('addomainid').reset();
+			dijit.byId('baseou').reset();
+		}
 		dijit.byId('subimagedlg').set('href', data.items.data.subimageurl);
 		dojo.byId('revisiondiv').innerHTML = data.items.data.revisionHTML;
 		dojo.byId('addeditdlgerrmsg').innerHTML = '';
@@ -111,6 +147,9 @@ function resetEditResource() {
 		dijit.byId('advancedoptions').toggle();
 	dojo.byId('connectmethodlist').innerHTML = '';
 	dojo.byId('addeditdlgerrmsg').innerHTML = '';
+	dijit.byId('adauthenable').reset();
+	dijit.byId('addomainid').reset();
+	dijit.byId('baseou').reset();
 }
 
 function saveResource() {
@@ -168,6 +207,12 @@ function saveResource() {
 		setTimeout(function() {dijit.byId('reload').focus();}, 300);
 		return;
 	}
+	if(dijit.byId('adauthenable').checked && ! checkValidatedObj('baseou', errobj)) {
+		if(! dijit.byId('advancedoptions').open)
+			dijit.byId('advancedoptions').toggle();
+		setTimeout(function() {dijit.byId('baseou').focus();}, 300);
+		return;
+	}
 
 	if(dojo.byId('editresid').value == 0)
 		var data = {continuation: dojo.byId('addresourcecont').value};
@@ -234,6 +279,16 @@ function saveResource() {
 	data['cpuspeed'] = dijit.byId('cpuspeed').get('value');
 	if(dijit.byId('reload'))
 		data['reload'] = dijit.byId('reload').get('value');
+	if(dijit.byId('adauthenable').checked) {
+		data['adauthenabled'] = 1;
+		data['addomainid'] = dijit.byId('addomainid').get('value');
+		data['baseou'] = dijit.byId('baseou').get('value');
+	}
+	else {
+		data['adauthenabled'] = 0;
+		data['addomainid'] = 0;
+		data['baseou'] = '';
+	}
 
 	submitbtn.set('disabled', true);
 	RPCwrapper(data, saveResourceCB, 1);
@@ -287,6 +342,10 @@ function saveResourceCB(data, ioArgs) {
 					resourcegrid.store.setValue(item, 'rootaccess', parseInt(data.items.data.rootaccess));
 					resourcegrid.store.setValue(item, 'sethostname', parseInt(data.items.data.sethostname));
 					resourcegrid.store.setValue(item, 'reloadtime', data.items.data.reloadtime);
+					resourcegrid.store.setValue(item, 'adauthenabled', data.items.data.adauthenabled);
+					resourcegrid.store.setValue(item, 'addomainid', data.items.data.addomainid);
+					resourcegrid.store.setValue(item, 'addomain', data.items.data.addomain);
+					resourcegrid.store.setValue(item, 'baseOU', data.items.data.baseOU);
 				},
 				onComplete: function(items, result) {
 					// when call resourcegrid.sort directly, the table contents disappear; not sure why
@@ -314,6 +373,11 @@ function saveResourceCB(data, ioArgs) {
 			dijit.byId('reload').reset();
 		dijit.byId('addeditdlg').hide();
 		dojo.byId('addeditdlgerrmsg').innerHTML = '';
+		if('extraaddomainid' in dijit.byId('addomainid')) {
+			dijit.byId('addomainid').removeOption({value: dijit.byId('addomainid').extraaddomainid});
+			delete dijit.byId('addomainid').extraaddomainid;
+			delete dijit.byId('addomainid').extraaddomainou;
+		}
 		dijit.registry.filter(function(widget, index){return widget.id.match(/^comments/);}).forEach(function(widget) {widget.destroy();});
 		setTimeout(function() {dijit.byId('addeditbtn').set('disabled', false);}, 250);
 	}
@@ -663,10 +727,17 @@ function startImageCB(data, ioArgs) {
 	}
 	else
 		dojo.addClass('sethostnamediv', 'hidden');
-	if(data.items.ostype == 'windows')
+	dijit.byId('adauthenable').set('checked', false);
+	dijit.byId('addomainid').reset();
+	dijit.byId('baseou').reset();
+	if(data.items.ostype == 'windows') {
 		dojo.removeClass('sysprepdiv', 'hidden');
-	else
+		dojo.removeClass('imageadauthbox', 'hidden');
+	}
+	else {
 		dojo.addClass('sysprepdiv', 'hidden');
+		dojo.addClass('imageadauthbox', 'hidden');
+	}
 
 	if(data.items.checkpoint) {
 		dojo.addClass('imageendrescontent', 'hidden');
@@ -763,3 +834,26 @@ function submitUpdateImageClickthroughCB(data, ioArgs) {
 	dijit.byId('clickthroughDlgBtn').set('disabled', false);
 	resRefresh();
 }
+
+function toggleADauth() {
+	if(dijit.byId('adauthenable').checked) {
+		dijit.byId('addomainid').set('disabled', false);
+		dijit.byId('baseou').set('disabled', false);
+	}
+	else {
+		dijit.byId('addomainid').set('disabled', true);
+		dijit.byId('baseou').set('disabled', true);
+	}
+	selectADauth();
+}
+
+function selectADauth() {
+	var obj = dijit.byId('addomainid');
+	if('extraaddomainid' in obj && obj.get('value') == obj.extraaddomainid) {
+		dijit.byId('baseou').set('value', obj.extraaddomainou);
+		dijit.byId('baseou').set('disabled', true);
+	}
+	else if(dijit.byId('adauthenable').checked) {
+		dijit.byId('baseou').set('disabled', false);
+	}
+}
