@@ -58,7 +58,6 @@ function VMHostDataCB(data, ioArgs) {
 		document.body.style.cursor = 'default';
 		return;
 	}
-	dojo.byId('vmlimit').value = data.items.vmlimit;
 	dojo.byId('vmhostdata').className = 'shown';
 
 	curprofileid = data.items.profileid;
@@ -102,6 +101,7 @@ function VMHostDataCB(data, ioArgs) {
 	for(var i = 0; i < data.items.currvms.length; i++) {
 		inobj.options[inobj.options.length] = new Option(data.items.currvms[i].name, data.items.currvms[i].id);
 	}
+	dojo.byId('assignedcnt').innerHTML = dojo.byId('currvms').options.length;
 	var outobj = dojo.byId('freevms');
 	for(var i = 0; i < data.items.freevms.length; i++) {
 		outobj.options[outobj.options.length] = new Option(data.items.freevms[i].name, data.items.freevms[i].id);
@@ -134,32 +134,6 @@ function VMHostDataCB(data, ioArgs) {
 	document.body.style.cursor = 'default';
 }
 
-function updateVMlimit(cont) {
-	var hostid = dojo.byId('vmhostid').value;
-	var newlimit = dojo.byId('vmlimit').value;
-	document.body.style.cursor = 'wait';
-
-	dojo.xhrPost({
-		url: 'index.php',
-		load: updateVMlimitCB,
-		handleAs: "json",
-		error: errorHandler,
-		content: {continuation: cont,
-					 vmhostid: hostid,
-					 newlimit: newlimit},
-		timeout: 15000
-	});
-}
-
-function updateVMlimitCB(data, ioArgs) {
-	if(data.items.status != 'SUCCESS') {
-		if(data.items.status == 'LIMIT')
-			dijit.byId('vmlimit').set('value', data.items.limit);
-		alert(data.items.msg);
-	}
-	document.body.style.cursor = 'default';
-}
-
 function showVMstate() {
 	var selobj = dojo.byId('currvms');
 	var cnt = 0;
@@ -176,56 +150,6 @@ function showVMstate() {
 		dojo.byId('vmstate').innerHTML = '';
 }
 
-function changeVMprofile() {
-	var hostid = dojo.byId('vmhostid').value;
-	var selobj = dojo.byId('vmprofileid');
-	var newid = selobj.options[selobj.selectedIndex].value;
-	dijit.byId('profileDlg').show();
-}
-
-function cancelVMprofileChange() {
-	if(fromok) {
-		fromok = 0;
-	}
-	else {
-		var selobj = dojo.byId('vmprofileid');
-		for(var i = 0; i < selobj.options.length; i++) {
-			if(selobj.options[i].value == curprofileid) {
-				selobj.selectedIndex = i;
-				break;
-			}
-		}
-	}
-}
-
-function submitChangeProfile() {
-	fromok = 1;
-	var hostid = dojo.byId('vmhostid').value;
-	var cont = dojo.byId('changevmcont').value;
-	var selobj = dojo.byId('vmprofileid');
-	var oldid = curprofileid;
-	var newid = selobj.options[selobj.selectedIndex].value;
-	dijit.byId('profileDlg').hide();
-	dojo.xhrPost({
-		url: 'index.php',
-		load: submitChangeProfileCB,
-		handleAs: "json",
-		error: errorHandler,
-		content: {continuation: cont,
-					 vmhostid: hostid,
-					 oldprofileid: oldid,
-					 newprofileid: newid},
-		timeout: 15000
-	});
-}
-
-function submitChangeProfileCB(data, ioArgs) {
-	var selobj = dojo.byId('vmprofileid');
-	curprofileid = selobj.options[selobj.selectedIndex].value;
-	dojo.byId('changevmcont').value = data.items.continuation;
-	alert(data.items.msg);
-}
-
 function vmToHost(cont) {
 	document.body.style.cursor = 'wait';
 	var hostid = dojo.byId('vmhostid').value;
@@ -237,14 +161,6 @@ function vmToHost(cont) {
 			listids.push(obj.options[i].value);
 		}
 	}
-	//var limit = dijit.byId('vmlimit').value;
-	var limit = dojo.byId('vmlimit').value;
-	var currcnt = dojo.byId('currvms').options.length;
-	if(limit < currcnt + listids.length) {
-		alert('You\'re attempting to add more VMs to this host\nthan the current VM limit.  This is not allowed.');
-		document.body.style.cursor = 'default';
-		return;
-	}
 
 	if(listids.length == 0) {
 		document.body.style.cursor = 'default';
@@ -267,8 +183,6 @@ function vmToHostCB(data, ioArgs) {
 	if(data.items.failed) {
 		if(data.items.failed == 'nohostaccess')
 			alert('You do not have access to manage this VM host.');
-		else if(data.items.failed == 'vmlimit')
-			alert('You\'re attempting to add more VMs to this host\nthan the current VM limit.  This is not allowed.');
 		document.body.style.cursor = 'default';
 		return;
 	}
@@ -342,6 +256,7 @@ function vmToHostCB(data, ioArgs) {
 				lastid = allvms[j].id;
 		}
 	}
+	dojo.byId('assignedcnt').innerHTML = dojo.byId('currvms').options.length;
 	document.body.style.cursor = 'default';
 	if(fails.length) {
 		var msg = '';
@@ -480,6 +395,7 @@ function vmFromHostCB(data, ioArgs) {
 		var func = function() {vmFromHostDelayed(data.items.cont);};
 		setMessageWindow('Delayed Move', 'Move Later', content, func);
 	}
+	dojo.byId('assignedcnt').innerHTML = dojo.byId('currvms').options.length;
 	document.body.style.cursor = 'default';
 }
 
@@ -603,8 +519,6 @@ function getVMprofileDataCB(data, ioArgs) {
 	dijit.byId('pvs2').noValueIndicator = '(empty)';
 	dijit.byId('pvs3').noValueIndicator = '(empty)';
 	dijit.byId('pusername').noValueIndicator = '(empty)';
-	dijit.byId('prsakey').noValueIndicator = '(empty)';
-	dijit.byId('prsapub').noValueIndicator = '(empty)';
 
 	dijit.byId('pname').setValue(curprofile.profilename);
 	dijit.byId('presourcepath').setValue(curprofile.resourcepath);
@@ -621,11 +535,15 @@ function getVMprofileDataCB(data, ioArgs) {
 	dijit.byId('pusername').setValue(curprofile.username);
 	dijit.byId('pgenmac0').setValue(curprofile.eth0generated);
 	dijit.byId('pgenmac1').setValue(curprofile.eth1generated);
-	dijit.byId('prsapub').setValue(curprofile.rsapub);
-	dijit.byId('prsakey').setValue(curprofile.rsakey);
-	dojo.byId('ppassword').value = curprofile.password;
-	dojo.byId('ppwdconfirm').value = curprofile.password;
-	checkProfilePassword();
+	if(curprofile.pwdlength == 0) {
+		dojo.byId('ppassword').value = '';
+		dojo.byId('ppwdconfirm').value = '';
+	}
+	else {
+		dojo.byId('ppassword').value = '********';
+		dojo.byId('ppwdconfirm').value = 'xxxxxxxx';
+	}
+	dojo.byId('ppwdmatch').innerHTML = '';
 	dojo.byId('vmprofiledata').className = 'shown';
 	document.body.style.cursor = 'default';
 }
@@ -797,8 +715,15 @@ function updateProfile(id, field) {
 		var newvalue = dojo.byId(id).value;
 	if(curprofile[field] == newvalue && field != 'password')
 		return;
-	if(field == 'password')
+	if(field == 'password') {
+		if(dojo.byId('ppassword').value == '********' &&
+		   dojo.byId('ppwdconfirm').value == 'xxxxxxxx') {
+			dojo.byId('savestatus').innerHTML = '(No change)';
+			setTimeout(function() {dojo.byId('savestatus').innerHTML = '';}, 3000);
+			return;
+		}
 		dojo.byId('savestatus').innerHTML = 'Saving...';
+	}
 	document.body.style.cursor = 'wait';
 	
 	var profileid = dojo.byId('profileid').value;
